import sys
import types
from _typeshed import Incomplete, ReadableBuffer, WriteableBuffer
from collections.abc import Callable, Hashable
from typing import Any, Literal, TypeVar, overload
from typing_extensions import TypeAlias

import _cffi_backend
from setuptools._distutils.extension import Extension

_T = TypeVar("_T")

basestring: TypeAlias = str  # noqa: Y042

class FFI:
    CData: TypeAlias = _cffi_backend._CDataBase
    CType: TypeAlias = _cffi_backend.CType
    buffer: TypeAlias = _cffi_backend.buffer  # noqa: Y042

    BVoidP: CType
    BCharA: CType
    NULL: CType
    errno: int

    def __init__(self, backend: types.ModuleType | None = None) -> None: ...
    def cdef(self, csource: str, override: bool = False, packed: bool = False, pack: int | None = None) -> None: ...
    def embedding_api(self, csource: str, packed: bool = False, pack: bool | int | None = None) -> None: ...

    if sys.platform == "win32":
        def dlopen(self, name: str, flags: int = ...) -> _cffi_backend.Lib: ...
    else:
        def dlopen(self, name: str | None, flags: int = ...) -> _cffi_backend.Lib: ...

    def dlclose(self, lib: _cffi_backend.Lib) -> None: ...
    def typeof(self, cdecl: str | CData | types.BuiltinFunctionType | types.FunctionType) -> CType: ...
    def sizeof(self, cdecl: str | CData) -> int: ...
    def alignof(self, cdecl: str | CData) -> int: ...
    def offsetof(self, cdecl: str | CData, *fields_or_indexes: str | int) -> int: ...
    def new(self, cdecl: str | CType, init: Incomplete | None = None) -> CData: ...
    def new_allocator(
        self,
        alloc: Callable[[int], CData] | None = None,
        free: Callable[[CData], Any] | None = None,
        should_clear_after_alloc: bool = True,
    ) -> _cffi_backend._Allocator: ...
    def cast(self, cdecl: str | CType, source: CData | int) -> CData: ...
    def string(self, cdata: CData, maxlen: int = -1) -> bytes | str: ...
    def unpack(self, cdata: CData, length: int) -> bytes | str | list[Any]: ...
    @overload
    def from_buffer(self, cdecl: ReadableBuffer, require_writable: Literal[False] = False) -> CData: ...
    @overload
    def from_buffer(self, cdecl: WriteableBuffer, require_writable: Literal[True]) -> CData: ...
    @overload
    def from_buffer(
        self, cdecl: str | CType, python_buffer: ReadableBuffer, require_writable: Literal[False] = False
    ) -> CData: ...
    @overload
    def from_buffer(self, cdecl: str | CType, python_buffer: WriteableBuffer, require_writable: Literal[True]) -> CData: ...
    def memmove(self, dest: CData | WriteableBuffer, src: CData | ReadableBuffer, n: int) -> None: ...
    @overload
    def callback(
        self,
        cdecl: str | CType,
        python_callable: None = None,
        error: Any = None,
        onerror: Callable[[Exception, Any, Any], None] | None = None,
    ) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    @overload
    def callback(
        self,
        cdecl: str | CType,
        python_callable: Callable[..., _T],
        error: Any = None,
        onerror: Callable[[Exception, Any, Any], None] | None = None,
    ) -> Callable[..., _T]: ...
    def getctype(self, cdecl: str | CType, replace_with: str = "") -> str: ...
    @overload
    def gc(self, cdata: CData, destructor: Callable[[CData], Any], size: int = 0) -> CData: ...
    @overload
    def gc(self, cdata: CData, destructor: None, size: int = 0) -> None: ...
    def verify(self, source: str = "", tmpdir: str | None = None, **kwargs: Any) -> _cffi_backend.Lib: ...
    # Technically exists on all OSs, but crashes on all but Windows. So we hide it in stubs
    if sys.platform == "win32":
        def getwinerror(self, code: int = -1) -> tuple[int, str] | None: ...

    def addressof(self, cdata: CData, *fields_or_indexes: str | int) -> CData: ...
    def include(self, ffi_to_include: FFI) -> None: ...
    def new_handle(self, x: Any) -> CData: ...
    def from_handle(self, x: CData) -> Any: ...
    def release(self, x: CData) -> None: ...
    def set_unicode(self, enabled_flag: bool) -> None: ...
    def set_source(self, module_name: str, source: str, source_extension: str = ".c", **kwds: Any) -> None: ...
    def set_source_pkgconfig(
        self, module_name: str, pkgconfig_libs: list[str], source: str, source_extension: str = ".c", **kwds: Any
    ) -> None: ...
    def distutils_extension(self, tmpdir: str = "build", verbose: bool = True) -> Extension: ...
    def emit_c_code(self, filename: str) -> None: ...
    def emit_python_code(self, filename: str) -> None: ...
    def compile(self, tmpdir: str = ".", verbose: int = 0, target: str | None = None, debug: bool | None = None) -> str: ...
    def init_once(self, func: Callable[[], Any], tag: Hashable) -> Any: ...
    def embedding_init_code(self, pysource: str) -> None: ...
    def def_extern(self, *args: Any, **kwds: Any) -> None: ...
    def list_types(self) -> tuple[list[str], list[str], list[str]]: ...



from typing import Any, ClassVar, Generic, TypeVar

from docutils import Component, nodes
from docutils.frontend import Values
from docutils.io import Input
from docutils.parsers import Parser
from docutils.transforms import Transform

_S = TypeVar("_S")

class Reader(Component, Generic[_S]):
    component_type: ClassVar[str]
    config_section: ClassVar[str]
    def get_transforms(self) -> list[type[Transform]]: ...
    def __init__(self, parser: Parser | None = None, parser_name: str | None = None) -> None: ...
    parser: Parser | None
    source: Input[_S] | None
    input: str | Any | None
    def set_parser(self, parser_name: str) -> None: ...
    def read(self, source: Input[_S], parser: Parser, settings: Values) -> nodes.document: ...
    document: nodes.document
    def parse(self) -> None: ...
    def new_document(self) -> nodes.document: ...

class ReReader(Reader[_S]):
    def get_transforms(self) -> list[type[Transform]]: ...

def get_reader_class(reader_name: str) -> type[Reader[Any]]: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Germany(WesternCalendar):
    include_labour_day: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    include_easter_monday: ClassVar[bool]
    include_ascension: ClassVar[bool]
    include_whit_monday: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    include_boxing_day: ClassVar[bool]
    boxing_day_label: ClassVar[str]
    all_time_include_reformation_day: ClassVar[bool]
    include_reformation_day_2018: ClassVar[bool]
    def include_reformation_day(self, year): ...
    def get_reformation_day(self, year): ...
    def get_variable_days(self, year): ...

class BadenWurttemberg(Germany):
    include_epiphany: ClassVar[bool]
    include_corpus_christi: ClassVar[bool]
    include_all_saints: ClassVar[bool]

class Bavaria(Germany):
    include_epiphany: ClassVar[bool]
    include_corpus_christi: ClassVar[bool]
    include_all_saints: ClassVar[bool]
    include_assumption: ClassVar[bool]

class Berlin(Germany):
    def get_international_womens_day(self, year): ...
    def get_liberation_day(self, year): ...
    def get_variable_days(self, year): ...

class Brandenburg(Germany):
    include_easter_sunday: ClassVar[bool]
    all_time_include_reformation_day: ClassVar[bool]

class Bremen(Germany):
    include_reformation_day_2018: ClassVar[bool]

class Hamburg(Germany):
    include_reformation_day_2018: ClassVar[bool]

class Hesse(Germany):
    include_corpus_christi: ClassVar[bool]

class MecklenburgVorpommern(Germany):
    all_time_include_reformation_day: ClassVar[bool]

class LowerSaxony(Germany):
    include_reformation_day_2018: ClassVar[bool]

class NorthRhineWestphalia(Germany):
    include_corpus_christi: ClassVar[bool]
    include_all_saints: ClassVar[bool]

class RhinelandPalatinate(Germany):
    include_corpus_christi: ClassVar[bool]
    include_all_saints: ClassVar[bool]

class Saarland(Germany):
    include_corpus_christi: ClassVar[bool]
    include_assumption: ClassVar[bool]
    include_all_saints: ClassVar[bool]

class Saxony(Germany):
    all_time_include_reformation_day: ClassVar[bool]
    def get_repentance_day(self, year): ...
    def get_variable_days(self, year): ...

class SaxonyAnhalt(Germany):
    include_epiphany: ClassVar[bool]
    all_time_include_reformation_day: ClassVar[bool]

class SchleswigHolstein(Germany):
    include_reformation_day_2018: ClassVar[bool]

class Thuringia(Germany):
    all_time_include_reformation_day: ClassVar[bool]



from _typeshed import Incomplete

from braintree.add_on import AddOn
from braintree.discount import Discount
from braintree.resource import Resource

class Plan(Resource):
    add_ons: list[AddOn]
    discounts: list[Discount]
    def __init__(self, gateway, attributes) -> None: ...
    @staticmethod
    def all(): ...
    @staticmethod
    def create(params: Incomplete | None = None): ...
    @staticmethod
    def find(subscription_id): ...
    @staticmethod
    def update(subscription_id, params: Incomplete | None = None): ...
    @staticmethod
    def create_signature(): ...
    @staticmethod
    def update_signature(): ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

class AppRole(VaultApiBase):
    def create_or_update_approle(
        self,
        role_name,
        bind_secret_id: Incomplete | None = None,
        secret_id_bound_cidrs: Incomplete | None = None,
        secret_id_num_uses: Incomplete | None = None,
        secret_id_ttl: Incomplete | None = None,
        enable_local_secret_ids: Incomplete | None = None,
        token_ttl: Incomplete | None = None,
        token_max_ttl: Incomplete | None = None,
        token_policies: Incomplete | None = None,
        token_bound_cidrs: Incomplete | None = None,
        token_explicit_max_ttl: Incomplete | None = None,
        token_no_default_policy: Incomplete | None = None,
        token_num_uses: Incomplete | None = None,
        token_period: Incomplete | None = None,
        token_type: Incomplete | None = None,
        mount_point="approle",
    ): ...
    def list_roles(self, mount_point="approle"): ...
    def read_role(self, role_name, mount_point="approle"): ...
    def delete_role(self, role_name, mount_point="approle"): ...
    def read_role_id(self, role_name, mount_point="approle"): ...
    def update_role_id(self, role_name, role_id, mount_point="approle"): ...
    def generate_secret_id(
        self,
        role_name,
        metadata: Incomplete | None = None,
        cidr_list: Incomplete | None = None,
        token_bound_cidrs: Incomplete | None = None,
        mount_point="approle",
        wrap_ttl: Incomplete | None = None,
    ): ...
    def create_custom_secret_id(
        self,
        role_name,
        secret_id,
        metadata: Incomplete | None = None,
        cidr_list: Incomplete | None = None,
        token_bound_cidrs: Incomplete | None = None,
        mount_point="approle",
        wrap_ttl: Incomplete | None = None,
    ): ...
    def read_secret_id(self, role_name, secret_id, mount_point="approle"): ...
    def destroy_secret_id(self, role_name, secret_id, mount_point="approle"): ...
    def list_secret_id_accessors(self, role_name, mount_point="approle"): ...
    def read_secret_id_accessor(self, role_name, secret_id_accessor, mount_point="approle"): ...
    def destroy_secret_id_accessor(self, role_name, secret_id_accessor, mount_point="approle"): ...
    def login(self, role_id, secret_id: Incomplete | None = None, use_token: bool = True, mount_point="approle"): ...



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

DEFAULT_MOUNT_POINT: str
logger: Incomplete

class Azure(VaultApiBase):
    def configure(
        self,
        tenant_id,
        resource,
        environment: Incomplete | None = None,
        client_id: Incomplete | None = None,
        client_secret: Incomplete | None = None,
        mount_point="azure",
    ): ...
    def read_config(self, mount_point="azure"): ...
    def delete_config(self, mount_point="azure"): ...
    def create_role(
        self,
        name,
        policies: Incomplete | None = None,
        ttl: Incomplete | None = None,
        max_ttl: Incomplete | None = None,
        period: Incomplete | None = None,
        bound_service_principal_ids: Incomplete | None = None,
        bound_group_ids: Incomplete | None = None,
        bound_locations: Incomplete | None = None,
        bound_subscription_ids: Incomplete | None = None,
        bound_resource_groups: Incomplete | None = None,
        bound_scale_sets: Incomplete | None = None,
        num_uses: Incomplete | None = None,
        mount_point="azure",
    ): ...
    def read_role(self, name, mount_point="azure"): ...
    def list_roles(self, mount_point="azure"): ...
    def delete_role(self, name, mount_point="azure"): ...
    def login(
        self,
        role,
        jwt,
        subscription_id: Incomplete | None = None,
        resource_group_name: Incomplete | None = None,
        vm_name: Incomplete | None = None,
        vmss_name: Incomplete | None = None,
        use_token: bool = True,
        mount_point="azure",
    ): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

__all__ = [
    "configuration_model",
    "directed_configuration_model",
    "expected_degree_graph",
    "havel_hakimi_graph",
    "directed_havel_hakimi_graph",
    "degree_sequence_tree",
    "random_degree_sequence_graph",
]

@_dispatch
def configuration_model(deg_sequence, create_using: Incomplete | None = None, seed: Incomplete | None = None): ...
@_dispatch
def directed_configuration_model(
    in_degree_sequence, out_degree_sequence, create_using: Incomplete | None = None, seed: Incomplete | None = None
): ...
@_dispatch
def expected_degree_graph(w, seed: Incomplete | None = None, selfloops: bool = True): ...
@_dispatch
def havel_hakimi_graph(deg_sequence, create_using: Incomplete | None = None): ...
@_dispatch
def directed_havel_hakimi_graph(in_deg_sequence, out_deg_sequence, create_using: Incomplete | None = None): ...
@_dispatch
def degree_sequence_tree(deg_sequence, create_using: Incomplete | None = None): ...
@_dispatch
def random_degree_sequence_graph(sequence, seed: Incomplete | None = None, tries: int = 10): ...

class DegreeSequenceRandomGraph:
    rng: Incomplete
    degree: Incomplete
    m: Incomplete
    dmax: Incomplete
    def __init__(self, degree, rng) -> None: ...
    remaining_degree: Incomplete
    graph: Incomplete
    def generate(self): ...
    def update_remaining(self, u, v, aux_graph: Incomplete | None = None) -> None: ...
    def p(self, u, v): ...
    def q(self, u, v): ...
    def suitable_edge(self): ...
    def phase1(self) -> None: ...
    def phase2(self) -> None: ...
    def phase3(self) -> None: ...



from collections.abc import Iterable, Mapping
from typing import NoReturn, Protocol

from paramiko.auth_strategy import AuthStrategy
from paramiko.channel import Channel, ChannelFile, ChannelStderrFile, ChannelStdinFile
from paramiko.hostkeys import HostKeys
from paramiko.pkey import PKey
from paramiko.sftp_client import SFTPClient
from paramiko.transport import Transport, _SocketLike
from paramiko.util import ClosingContextManager

class _TransportFactory(Protocol):
    def __call__(
        self,
        sock: _SocketLike,
        /,
        *,
        gss_kex: bool,
        gss_deleg_creds: bool,
        disabled_algorithms: Mapping[str, Iterable[str]] | None,
    ) -> Transport: ...

class SSHClient(ClosingContextManager):
    def __init__(self) -> None: ...
    def load_system_host_keys(self, filename: str | None = None) -> None: ...
    def load_host_keys(self, filename: str) -> None: ...
    def save_host_keys(self, filename: str) -> None: ...
    def get_host_keys(self) -> HostKeys: ...
    def set_log_channel(self, name: str) -> None: ...
    def set_missing_host_key_policy(self, policy: type[MissingHostKeyPolicy] | MissingHostKeyPolicy) -> None: ...
    def connect(
        self,
        hostname: str,
        port: int = 22,
        username: str | None = None,
        password: str | None = None,
        pkey: PKey | None = None,
        key_filename: str | None = None,
        timeout: float | None = None,
        allow_agent: bool = True,
        look_for_keys: bool = True,
        compress: bool = False,
        sock: _SocketLike | None = None,
        gss_auth: bool = False,
        gss_kex: bool = False,
        gss_deleg_creds: bool = True,
        gss_host: str | None = None,
        banner_timeout: float | None = None,
        auth_timeout: float | None = None,
        channel_timeout: float | None = None,
        gss_trust_dns: bool = True,
        passphrase: str | None = None,
        disabled_algorithms: Mapping[str, Iterable[str]] | None = None,
        transport_factory: _TransportFactory | None = None,
        auth_strategy: AuthStrategy | None = None,
    ) -> None: ...
    def close(self) -> None: ...
    def exec_command(
        self,
        command: str,
        bufsize: int = -1,
        timeout: float | None = None,
        get_pty: bool = False,
        environment: Mapping[str, str] | None = None,
    ) -> tuple[ChannelStdinFile, ChannelFile, ChannelStderrFile]: ...
    def invoke_shell(
        self,
        term: str = "vt100",
        width: int = 80,
        height: int = 24,
        width_pixels: int = 0,
        height_pixels: int = 0,
        environment: Mapping[str, str] | None = None,
    ) -> Channel: ...
    def open_sftp(self) -> SFTPClient: ...
    def get_transport(self) -> Transport | None: ...

class MissingHostKeyPolicy:
    def missing_host_key(self, client: SSHClient, hostname: str, key: PKey) -> None: ...

class AutoAddPolicy(MissingHostKeyPolicy):
    def missing_host_key(self, client: SSHClient, hostname: str, key: PKey) -> None: ...

class RejectPolicy(MissingHostKeyPolicy):
    def missing_host_key(self, client: SSHClient, hostname: str, key: PKey) -> NoReturn: ...

class WarningPolicy(MissingHostKeyPolicy):
    def missing_host_key(self, client: SSHClient, hostname: str, key: PKey) -> None: ...



from netaddr.ip import _IPAddressAddr

def chr_range(low: str, high: str) -> list[str]: ...

BASE_85: list[str]
BASE_85_DICT: dict[str, int]

def ipv6_to_base85(addr: _IPAddressAddr) -> str: ...
def base85_to_ipv6(addr: str) -> str: ...



from _typeshed import Incomplete
from typing import Any, TypedDict

from flask import Flask
from flask.testing import FlaskClient

class _Packet(TypedDict):
    name: str
    args: Any
    namespace: str

class SocketIOTestClient:
    def __init__(
        self,
        app: Flask,
        socketio,
        namespace: str | None = None,
        query_string: str | None = None,
        headers: dict[str, Incomplete] | None = None,
        auth: dict[str, Incomplete] | None = None,
        flask_test_client: FlaskClient | None = None,
    ) -> None: ...
    def is_connected(self, namespace: str | None = None) -> bool: ...
    def connect(
        self,
        namespace: str | None = None,
        query_string: str | None = None,
        headers: dict[str, Incomplete] | None = None,
        auth: dict[str, Incomplete] | None = None,
    ) -> None: ...
    def disconnect(self, namespace: str | None = None) -> None: ...
    def emit(self, event: str, *args, callback: bool = True, namespace: str | None = None) -> Incomplete | None: ...
    def send(
        self,
        data: str | dict[str, Incomplete] | list[Incomplete],
        json: bool = False,
        callback: bool = False,
        namespace: str | None = None,
    ): ...
    def get_received(self, namespace: str | None = None) -> list[_Packet]: ...



NOT_NULL: int
PRI_KEY: int
UNIQUE_KEY: int
MULTIPLE_KEY: int
BLOB: int
UNSIGNED: int
ZEROFILL: int
BINARY: int
ENUM: int
AUTO_INCREMENT: int
TIMESTAMP: int
SET: int
PART_KEY: int
GROUP: int
UNIQUE: int



from _typeshed import Incomplete
from typing import ClassVar

from ..core import OrthodoxCalendar

class Belarus(OrthodoxCalendar):
    include_labour_day: ClassVar[bool]
    include_christmas: ClassVar[bool]
    christmas_day_label: ClassVar[str]
    orthodox_christmas_day_label: ClassVar[str]
    FIXED_HOLIDAYS: Incomplete
    def get_radonitsa(self, year): ...
    def get_variable_days(self, year): ...



from types import ModuleType
from typing import Any

class MonkeyPatchWarning(RuntimeWarning): ...

def is_module_patched(mod_name: str) -> bool: ...
def is_object_patched(mod_name: str, item_name: str) -> bool: ...
def get_original(mod_name: str, item_name: str) -> Any: ...
def patch_module(target_module: ModuleType, source_module: ModuleType, items: list[str] | None = None) -> bool: ...
def patch_os() -> None: ...
def patch_queue() -> None: ...
def patch_time() -> None: ...
def patch_thread(
    threading: bool = True, _threading_local: bool = True, Event: bool = True, logging: bool = True, existing_locks: bool = True
) -> None: ...
def patch_socket(dns: bool = True, aggressive: bool = True) -> None: ...
def patch_dns() -> None: ...
def patch_ssl() -> None: ...
def patch_select(aggressive: bool = True) -> None: ...
def patch_selectors(aggressive: bool = True) -> None: ...
def patch_subprocess() -> None: ...
def patch_signal() -> None: ...
def patch_all(
    socket: bool = True,
    dns: bool = True,
    time: bool = True,
    select: bool = True,
    thread: bool = True,
    os: bool = True,
    ssl: bool = True,
    subprocess: bool = True,
    sys: bool = False,
    aggressive: bool = True,
    Event: bool = True,
    builtins: bool = True,  # does nothing on Python 3
    signal: bool = True,
    queue: bool = True,
    contextvars: bool = True,  # does nothing on Python 3.7+
    **kwargs: object,
) -> bool | None: ...
def main() -> dict[str, Any]: ...



import io
from _typeshed import (
    FileDescriptorOrPath,
    OpenBinaryMode,
    OpenBinaryModeReading,
    OpenBinaryModeUpdating,
    OpenBinaryModeWriting,
    OpenTextMode,
    ReadableBuffer,
)
from types import TracebackType
from typing import IO, Any, AnyStr, ClassVar, Generic, Literal, TypeVar, overload
from typing_extensions import Self

from gevent.lock import DummySemaphore, Semaphore
from gevent.threadpool import ThreadPool

_IOT = TypeVar("_IOT", bound=IO[Any])

class cancel_wait_ex(IOError):
    def __init__(self) -> None: ...

class FileObjectClosed(IOError):
    def __init__(self) -> None: ...

class FlushingBufferedWriter(io.BufferedWriter): ...

class WriteallMixin:
    def writeall(self, b: ReadableBuffer, /) -> int: ...

class FileIO(io.FileIO): ...

class WriteIsWriteallMixin(WriteallMixin):
    def write(self, b: ReadableBuffer, /) -> int: ...

class WriteallFileIO(WriteIsWriteallMixin, io.FileIO): ...  # type: ignore[misc]

class OpenDescriptor(Generic[_IOT]):
    default_buffer_size: ClassVar[int]
    fileio_mode: str
    mode: str
    creating: bool
    reading: bool
    writing: bool
    appending: bool
    updating: bool
    text: bool
    binary: bool
    can_write: bool
    can_read: bool
    native: bool
    universal: bool
    buffering: int
    encoding: str | None
    errors: str | None
    newline: bool
    closefd: bool
    atomic_write: bool
    # we could add all the necessary overloads here too, but since this is internal API
    # I don't think it makes sense to do that
    def __init__(
        self,
        fobj: FileDescriptorOrPath,
        mode: str = "r",
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...
    def is_fd(self) -> bool: ...
    def opened(self) -> _IOT: ...
    def opened_raw(self) -> FileIO: ...
    @staticmethod
    def is_buffered(stream: object) -> bool: ...
    @classmethod
    def buffer_size_for_stream(cls, stream: object) -> int: ...

class FileObjectBase(Generic[_IOT, AnyStr]):
    def __init__(self: FileObjectBase[_IOT, AnyStr], descriptor: OpenDescriptor[_IOT]) -> None: ...
    io: _IOT
    @property
    def closed(self) -> bool: ...
    def close(self) -> None: ...
    def __getattr__(self, name: str) -> Any: ...
    def __enter__(self) -> Self: ...
    def __exit__(self, typ: type[BaseException] | None, value: BaseException | None, tb: TracebackType | None, /) -> None: ...
    def __iter__(self) -> Self: ...
    def __next__(self) -> AnyStr: ...
    def __bool__(self) -> bool: ...
    next = __next__

class FileObjectBlock(FileObjectBase[_IOT, AnyStr]):
    # Text mode: always binds a TextIOWrapper
    @overload
    def __init__(
        self: FileObjectBlock[io.TextIOWrapper, str],
        fobj: FileDescriptorOrPath,
        mode: OpenTextMode = "r",
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...

    # Unbuffered binary mode: binds a FileIO
    @overload
    def __init__(
        self: FileObjectBlock[io.FileIO, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryMode,
        bufsize: Literal[0],
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[0] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...
    @overload
    def __init__(
        self: FileObjectBlock[io.FileIO, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryMode,
        bufsize: Literal[0] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        *,
        buffering: Literal[0],
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...

    # Buffering is on: return BufferedRandom, BufferedReader, or BufferedWriter
    @overload
    def __init__(
        self: FileObjectBlock[io.BufferedRandom, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryModeUpdating,
        bufsize: Literal[-1, 1] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[-1, 1] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...
    @overload
    def __init__(
        self: FileObjectBlock[io.BufferedWriter, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryModeWriting,
        bufsize: Literal[-1, 1] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[-1, 1] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...
    @overload
    def __init__(
        self: FileObjectBlock[io.BufferedReader, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryModeReading,
        bufsize: Literal[-1, 1] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[-1, 1] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...

    # Buffering cannot be determined: fall back to BinaryIO
    @overload
    def __init__(
        self: FileObjectBlock[IO[bytes], bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryMode,
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...

    # Fallback if mode is not specified
    @overload
    def __init__(
        self: FileObjectBlock[IO[Any], Any],
        fobj: FileDescriptorOrPath,
        mode: str,
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
    ) -> None: ...

class FileObjectThread(FileObjectBase[_IOT, AnyStr]):
    threadpool: ThreadPool
    lock: Semaphore | DummySemaphore
    # Text mode: always binds a TextIOWrapper
    @overload
    def __init__(
        self: FileObjectThread[io.TextIOWrapper, str],
        fobj: FileDescriptorOrPath,
        mode: OpenTextMode = "r",
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...

    # Unbuffered binary mode: binds a FileIO
    @overload
    def __init__(
        self: FileObjectThread[io.FileIO, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryMode,
        bufsize: Literal[0],
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[0] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...
    @overload
    def __init__(
        self: FileObjectThread[io.FileIO, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryMode,
        bufsize: Literal[0] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        *,
        buffering: Literal[0],
        closefd: bool | None = None,
        atomic_write: bool = False,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...

    # Buffering is on: return BufferedRandom, BufferedReader, or BufferedWriter
    @overload
    def __init__(
        self: FileObjectThread[io.BufferedRandom, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryModeUpdating,
        bufsize: Literal[-1, 1] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[-1, 1] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...
    @overload
    def __init__(
        self: FileObjectThread[io.BufferedWriter, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryModeWriting,
        bufsize: Literal[-1, 1] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[-1, 1] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...
    @overload
    def __init__(
        self: FileObjectThread[io.BufferedReader, bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryModeReading,
        bufsize: Literal[-1, 1] | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: Literal[-1, 1] | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...

    # Buffering cannot be determined: fall back to BinaryIO
    @overload
    def __init__(
        self: FileObjectThread[IO[bytes], bytes],
        fobj: FileDescriptorOrPath,
        mode: OpenBinaryMode,
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...

    # Fallback if mode is not specified
    @overload
    def __init__(
        self: FileObjectThread[IO[Any], Any],
        fobj: FileDescriptorOrPath,
        mode: str,
        bufsize: int | None = None,
        close: bool | None = None,
        encoding: str | None = None,
        errors: str | None = None,
        newline: str | None = None,
        buffering: int | None = None,
        closefd: bool | None = None,
        atomic_write: bool = False,
        *,
        lock: bool = True,
        threadpool: ThreadPool | None = None,
    ) -> None: ...



from abc import ABCMeta, abstractmethod
from collections.abc import Sequence
from logging import Logger
from typing import Any

from hvac.adapters import Adapter
from hvac.api.vault_api_base import VaultApiBase

logger: Logger

class VaultApiCategory(VaultApiBase, metaclass=ABCMeta):
    implemented_class_names: Sequence[str]
    def __init__(self, adapter: Adapter[Any]) -> None: ...
    def __getattr__(self, item): ...
    @property
    def adapter(self) -> Adapter[Any]: ...
    @adapter.setter
    def adapter(self, adapter: Adapter[Any]) -> None: ...
    @property
    @abstractmethod
    def implemented_classes(self): ...
    @property
    def unimplemented_classes(self) -> None: ...
    @staticmethod
    def get_private_attr_name(class_name): ...



import abc
from _typeshed import Incomplete

import qrcode.image.base
from qrcode.image.styles.colormasks import QRColorMask
from qrcode.image.styles.moduledrawers import SquareModuleDrawer

class StyledPilImage(qrcode.image.base.BaseImageWithDrawer, metaclass=abc.ABCMeta):
    kind: str
    needs_processing: bool
    color_mask: QRColorMask
    default_drawer_class = SquareModuleDrawer
    embeded_image: Incomplete
    embeded_image_resample: Incomplete
    paint_color: Incomplete
    def __init__(self, *args, **kwargs) -> None: ...
    def new_image(self, **kwargs): ...
    def init_new_image(self) -> None: ...
    def process(self) -> None: ...
    def draw_embeded_image(self) -> None: ...
    def save(self, stream, format: Incomplete | None = None, **kwargs) -> None: ...  # type: ignore[override]
    def __getattr__(self, name): ...



from collections.abc import Callable, Mapping
from typing import Any, Generic, TypeVar, overload

_T = TypeVar("_T")
_S = TypeVar("_S")

class _SingleDispatchCallable(Generic[_T]):
    registry: Mapping[Any, Callable[..., _T]]
    def dispatch(self, cls: Any) -> Callable[..., _T]: ...
    @overload
    def register(self, cls: Any) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    @overload
    def register(self, cls: Any, func: Callable[..., _T]) -> Callable[..., _T]: ...
    def _clear_cache(self) -> None: ...
    def __call__(self, *args: Any, **kwargs: Any) -> _T: ...

def singledispatch(func: Callable[..., _T]) -> _SingleDispatchCallable[_T]: ...

class singledispatchmethod(Generic[_T]):
    dispatcher: _SingleDispatchCallable[_T]
    func: Callable[..., _T]
    def __init__(self, func: Callable[..., _T]) -> None: ...
    @property
    def __isabstractmethod__(self) -> bool: ...
    @overload
    def register(self, cls: type[Any], method: None = ...) -> Callable[[Callable[..., _T]], Callable[..., _T]]: ...
    @overload
    def register(self, cls: Callable[..., _T], method: None = ...) -> Callable[..., _T]: ...
    @overload
    def register(self, cls: type[Any], method: Callable[..., _T]) -> Callable[..., _T]: ...
    def __get__(self, obj: _S, cls: type[_S] | None = ...) -> Callable[..., _T]: ...



from _typeshed import Incomplete
from typing import ClassVar

from .core import UnitedStates

class Vermont(UnitedStates):
    FIXED_HOLIDAYS: Incomplete
    include_columbus_day: ClassVar[bool]
    def get_variable_days(self, year): ...



from _typeshed import Incomplete

class DisputeGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def accept(self, dispute_id): ...
    def add_file_evidence(self, dispute_id, document_upload_id_or_request): ...
    def add_text_evidence(self, dispute_id, content_or_request): ...
    def finalize(self, dispute_id): ...
    def find(self, dispute_id): ...
    def remove_evidence(self, dispute_id, evidence_id): ...
    search_criteria: dict[Incomplete, Incomplete]
    def search(self, *query): ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import WesternCalendar

class Panama(WesternCalendar):
    include_labour_day: ClassVar[bool]
    include_good_friday: ClassVar[bool]
    include_easter_saturday: ClassVar[bool]
    include_easter_sunday: ClassVar[bool]
    FIXED_HOLIDAYS: Incomplete
    def get_variable_days(self, year): ...



from collections.abc import Generator, Hashable

from networkx.classes.graph import Graph, _Node
from networkx.utils.backends import _dispatch

@_dispatch
def weakly_connected_components(G: Graph[_Node]) -> Generator[set[_Node], None, None]: ...
@_dispatch
def number_weakly_connected_components(G: Graph[Hashable]) -> int: ...
@_dispatch
def is_weakly_connected(G: Graph[Hashable]) -> bool: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def preflow_push(
    G,
    s,
    t,
    capacity: str = "capacity",
    residual: Incomplete | None = None,
    global_relabel_freq: float = 1,
    value_only: bool = False,
): ...



from influxdb_client.client.influxdb_client import InfluxDBClient
from influxdb_client.domain.organization import Organization

def get_org_query_param(org: Organization | str | None, client: InfluxDBClient, required_id: bool = False) -> str: ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class ReadyService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def get_ready(self, **kwargs): ...
    def get_ready_with_http_info(self, **kwargs): ...
    async def get_ready_async(self, **kwargs): ...



from _typeshed import Incomplete

from .FontFile import FontFile

PCF_MAGIC: int
PCF_PROPERTIES: Incomplete
PCF_ACCELERATORS: Incomplete
PCF_METRICS: Incomplete
PCF_BITMAPS: Incomplete
PCF_INK_METRICS: Incomplete
PCF_BDF_ENCODINGS: Incomplete
PCF_SWIDTHS: Incomplete
PCF_GLYPH_NAMES: Incomplete
PCF_BDF_ACCELERATORS: Incomplete
BYTES_PER_ROW: Incomplete

def sz(s, o): ...

class PcfFontFile(FontFile):
    name: str
    charset_encoding: Incomplete
    toc: Incomplete
    fp: Incomplete
    info: Incomplete
    def __init__(self, fp, charset_encoding: str = "iso8859-1") -> None: ...



from _curses import *
from _curses import _CursesWindow as _CursesWindow
from collections.abc import Callable
from typing import TypeVar
from typing_extensions import Concatenate, ParamSpec

# NOTE: The _curses module is ordinarily only available on Unix, but the
# windows-curses package makes it available on Windows as well with the same
# contents.

_T = TypeVar("_T")
_P = ParamSpec("_P")

# available after calling `curses.initscr()`
LINES: int
COLS: int

# available after calling `curses.start_color()`
COLORS: int
COLOR_PAIRS: int

def wrapper(func: Callable[Concatenate[_CursesWindow, _P], _T], /, *arg: _P.args, **kwds: _P.kwargs) -> _T: ...



from _typeshed import Incomplete
from typing import ClassVar

from ..core import IslamicCalendar

class Turkey(IslamicCalendar):
    shift_new_years_day: ClassVar[bool]
    WEEKEND_DAYS: Incomplete
    include_eid_al_fitr: ClassVar[bool]
    length_eid_al_fitr: int
    include_eid_al_adha: ClassVar[bool]
    length_eid_al_adha: int
    include_labour_day: ClassVar[bool]
    labour_day_label: ClassVar[str]
    FIXED_HOLIDAYS: Incomplete
    def get_delta_islamic_holidays(self, year): ...



from braintree.search import Search

class UsBankAccountVerificationSearch:
    account_holder_name: Search.TextNodeBuilder
    customer_email: Search.TextNodeBuilder
    customer_id: Search.TextNodeBuilder
    id: Search.TextNodeBuilder
    payment_method_token: Search.TextNodeBuilder
    routing_number: Search.TextNodeBuilder
    ids: Search.MultipleValueNodeBuilder
    status: Search.MultipleValueNodeBuilder
    verification_method: Search.MultipleValueNodeBuilder
    created_at: Search.RangeNodeBuilder
    account_type: Search.EqualityNodeBuilder
    account_number: Search.EndsWithNodeBuilder



from _typeshed import Incomplete

from hvac.api.vault_api_base import VaultApiBase

DEFAULT_MOUNT_POINT: str

class Consul(VaultApiBase):
    def configure_access(self, address, token, scheme: Incomplete | None = None, mount_point="consul"): ...
    def create_or_update_role(
        self,
        name,
        policy: Incomplete | None = None,
        policies: Incomplete | None = None,
        token_type: Incomplete | None = None,
        local: Incomplete | None = None,
        ttl: Incomplete | None = None,
        max_ttl: Incomplete | None = None,
        mount_point="consul",
    ): ...
    def read_role(self, name, mount_point="consul"): ...
    def list_roles(self, mount_point="consul"): ...
    def delete_role(self, name, mount_point="consul"): ...
    def generate_credentials(self, name, mount_point="consul"): ...



from hvac.api.system_backend.system_backend_mixin import SystemBackendMixin

class Policy(SystemBackendMixin):
    def list_policies(self): ...
    def read_policy(self, name): ...
    def create_or_update_policy(self, name, policy, pretty_print: bool = True): ...
    def delete_policy(self, name): ...



from _typeshed import Incomplete

class DeletePredicateRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self, start: Incomplete | None = None, stop: Incomplete | None = None, predicate: Incomplete | None = None
    ) -> None: ...
    @property
    def start(self): ...
    @start.setter
    def start(self, start) -> None: ...
    @property
    def stop(self): ...
    @stop.setter
    def stop(self, stop) -> None: ...
    @property
    def predicate(self): ...
    @predicate.setter
    def predicate(self, predicate) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from collections.abc import Sequence

def clamp(x: float, lower: float = ..., upper: float = ...) -> float: ...
def ceil(x: float, options: Sequence[float] | None = None) -> float: ...
def floor(x: float, options: Sequence[float] | None = None) -> float: ...

class Bits:
    val: int
    len: int
    def __init__(self, val: int | list[bool] | str | bytes = 0, len_: int | None = None) -> None: ...
    def __getitem__(self, k) -> Bits | bool: ...
    def __len__(self) -> int: ...
    def __eq__(self, other) -> bool: ...
    def __or__(self, other: Bits) -> Bits: ...
    def __and__(self, other: Bits) -> Bits: ...
    def __lshift__(self, other: int) -> Bits: ...
    def __rshift__(self, other: int) -> Bits: ...
    def __hash__(self) -> int: ...
    def as_list(self) -> list[bool]: ...
    def as_bin(self) -> str: ...
    def as_hex(self) -> str: ...
    def as_int(self) -> int: ...
    def as_bytes(self) -> bytes: ...
    @classmethod
    def from_list(cls, list_): ...
    @classmethod
    def from_bin(cls, bin): ...
    @classmethod
    def from_hex(cls, hex): ...
    @classmethod
    def from_int(cls, int_, len_: int | None = None): ...
    @classmethod
    def from_bytes(cls, bytes_): ...



from typing import Any

class Result:
    total: Any
    duration: Any
    docs: Any
    def __init__(self, res, hascontent, duration: int = 0, has_payload: bool = False, with_scores: bool = False) -> None: ...



from _typeshed import Incomplete
from collections.abc import Iterable, Sequence

error = RuntimeError

def LocatePythonServiceExe(exe: Incomplete | None = ...): ...
def SmartOpenService(hscm, name, access): ...
def LocateSpecificServiceExe(serviceName): ...
def InstallPerfmonForService(serviceName, iniName, dllName: Incomplete | None = ...) -> None: ...
def InstallService(
    pythonClassString,
    serviceName,
    displayName,
    startType: Incomplete | None = ...,
    errorControl: Incomplete | None = ...,
    bRunInteractive: int = ...,
    serviceDeps: Incomplete | None = ...,
    userName: Incomplete | None = ...,
    password: Incomplete | None = ...,
    exeName: Incomplete | None = ...,
    perfMonIni: Incomplete | None = ...,
    perfMonDll: Incomplete | None = ...,
    exeArgs: Incomplete | None = ...,
    description: Incomplete | None = ...,
    delayedstart: Incomplete | None = ...,
) -> None: ...
def ChangeServiceConfig(
    pythonClassString,
    serviceName,
    startType: Incomplete | None = ...,
    errorControl: Incomplete | None = ...,
    bRunInteractive: int = ...,
    serviceDeps: Incomplete | None = ...,
    userName: Incomplete | None = ...,
    password: Incomplete | None = ...,
    exeName: Incomplete | None = ...,
    displayName: Incomplete | None = ...,
    perfMonIni: Incomplete | None = ...,
    perfMonDll: Incomplete | None = ...,
    exeArgs: Incomplete | None = ...,
    description: Incomplete | None = ...,
    delayedstart: Incomplete | None = ...,
) -> None: ...
def InstallPythonClassString(pythonClassString, serviceName) -> None: ...
def SetServiceCustomOption(serviceName, option, value) -> None: ...
def GetServiceCustomOption(serviceName, option, defaultValue: Incomplete | None = ...): ...
def RemoveService(serviceName) -> None: ...
def ControlService(serviceName, code, machine: Incomplete | None = ...): ...
def WaitForServiceStatus(serviceName, status, waitSecs, machine: Incomplete | None = ...) -> None: ...
def StopServiceWithDeps(serviceName, machine: Incomplete | None = ..., waitSecs: int = ...) -> None: ...
def StopService(serviceName, machine: Incomplete | None = ...): ...
def StartService(serviceName, args: Incomplete | None = ..., machine: Incomplete | None = ...) -> None: ...
def RestartService(
    serviceName, args: Incomplete | None = ..., waitSeconds: int = ..., machine: Incomplete | None = ...
) -> None: ...
def DebugService(cls, argv=...) -> None: ...
def GetServiceClassString(cls, argv: Incomplete | None = ...): ...
def QueryServiceStatus(serviceName, machine: Incomplete | None = ...): ...
def usage() -> None: ...
def HandleCommandLine(
    cls: type[ServiceFramework],
    serviceClassString: Incomplete | None = ...,
    argv: Sequence[str] | None = ...,
    customInstallOptions: str = ...,
    customOptionHandler: Incomplete | None = ...,
): ...

class ServiceFramework:
    ssh: Incomplete
    checkPoint: int
    def __init__(self, args: Iterable[str]) -> None: ...
    def GetAcceptedControls(self): ...
    def ReportServiceStatus(
        self, serviceStatus, waitHint: int = ..., win32ExitCode: int = ..., svcExitCode: int = ...
    ) -> None: ...
    def SvcInterrogate(self) -> None: ...
    def SvcOther(self, control) -> None: ...
    def ServiceCtrlHandler(self, control): ...
    def SvcOtherEx(self, control, event_type, data): ...
    def ServiceCtrlHandlerEx(self, control, event_type, data): ...
    def SvcRun(self) -> None: ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class SourcesService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_sources_id(self, source_id, **kwargs): ...
    def delete_sources_id_with_http_info(self, source_id, **kwargs): ...
    async def delete_sources_id_async(self, source_id, **kwargs): ...
    def get_sources(self, **kwargs): ...
    def get_sources_with_http_info(self, **kwargs): ...
    async def get_sources_async(self, **kwargs): ...
    def get_sources_id(self, source_id, **kwargs): ...
    def get_sources_id_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_async(self, source_id, **kwargs): ...
    def get_sources_id_buckets(self, source_id, **kwargs): ...
    def get_sources_id_buckets_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_buckets_async(self, source_id, **kwargs): ...
    def get_sources_id_health(self, source_id, **kwargs): ...
    def get_sources_id_health_with_http_info(self, source_id, **kwargs): ...
    async def get_sources_id_health_async(self, source_id, **kwargs): ...
    def patch_sources_id(self, source_id, source, **kwargs): ...
    def patch_sources_id_with_http_info(self, source_id, source, **kwargs): ...
    async def patch_sources_id_async(self, source_id, source, **kwargs): ...
    def post_sources(self, source, **kwargs): ...
    def post_sources_with_http_info(self, source, **kwargs): ...
    async def post_sources_async(self, source, **kwargs): ...



from _typeshed import Incomplete

class DBRP:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        id: Incomplete | None = None,
        org_id: Incomplete | None = None,
        bucket_id: Incomplete | None = None,
        database: Incomplete | None = None,
        retention_policy: Incomplete | None = None,
        default: Incomplete | None = None,
        virtual: bool | None = None,
        links: Incomplete | None = None,
    ) -> None: ...
    @property
    def id(self): ...
    @id.setter
    def id(self, id) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    @property
    def bucket_id(self): ...
    @bucket_id.setter
    def bucket_id(self, bucket_id) -> None: ...
    @property
    def database(self): ...
    @database.setter
    def database(self, database) -> None: ...
    @property
    def retention_policy(self): ...
    @retention_policy.setter
    def retention_policy(self, retention_policy) -> None: ...
    @property
    def default(self): ...
    @default.setter
    def default(self, default) -> None: ...
    virtual: bool | None
    @property
    def links(self): ...
    @links.setter
    def links(self, links) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def is_valid_joint_degree(joint_degrees): ...
@_dispatch
def joint_degree_graph(joint_degrees, seed: Incomplete | None = None): ...
@_dispatch
def is_valid_directed_joint_degree(in_degrees, out_degrees, nkk): ...
@_dispatch
def directed_joint_degree_graph(in_degrees, out_degrees, nkk, seed: Incomplete | None = None): ...



from _typeshed import Incomplete

def to_latex_raw(
    G,
    pos: str = "pos",
    tikz_options: str = "",
    default_node_options: str = "",
    node_options: str = "node_options",
    node_label: str = "label",
    default_edge_options: str = "",
    edge_options: str = "edge_options",
    edge_label: str = "label",
    edge_label_options: str = "edge_label_options",
): ...
def to_latex(
    Gbunch,
    pos: str = "pos",
    tikz_options: str = "",
    default_node_options: str = "",
    node_options: str = "node_options",
    node_label: str = "node_label",
    default_edge_options: str = "",
    edge_options: str = "edge_options",
    edge_label: str = "edge_label",
    edge_label_options: str = "edge_label_options",
    caption: str = "",
    latex_label: str = "",
    sub_captions: Incomplete | None = None,
    sub_labels: Incomplete | None = None,
    n_rows: int = 1,
    as_document: bool = True,
    document_wrapper: str = ...,
    figure_wrapper: str = ...,
    subfigure_wrapper: str = ...,
): ...
def write_latex(Gbunch, path, **options) -> None: ...



from _typeshed import Incomplete
from collections import OrderedDict
from typing import TypeVar

from humanfriendly.compat import unicode

_KT = TypeVar("_KT")
_VT = TypeVar("_VT")

class CaseInsensitiveDict(OrderedDict[_KT, _VT]):
    def __init__(self, other: Incomplete | None = None, **kw) -> None: ...
    def coerce_key(self, key): ...
    @classmethod
    def fromkeys(cls, iterable, value: Incomplete | None = None): ...
    def get(self, key, default: Incomplete | None = None): ...
    def pop(self, key, default: Incomplete | None = None): ...
    def setdefault(self, key, default: Incomplete | None = None): ...
    def update(self, other: Incomplete | None = None, **kw) -> None: ...  # type: ignore[override]
    def __contains__(self, key): ...
    def __delitem__(self, key) -> None: ...
    def __getitem__(self, key): ...
    def __setitem__(self, key, value) -> None: ...

class CaseInsensitiveKey(unicode):
    def __new__(cls, value): ...
    def __hash__(self) -> int: ...
    def __eq__(self, other): ...



import logging
from typing import TextIO

TEXT_NORMAL: int
TEXT_BOLD: int
TEXT_RED: int
TEXT_GREEN: int
TEXT_YELLOW: int
TEXT_BLUE: int
TEXT_MAGENTA: int
TEXT_CYAN: int

def get_logger() -> logging.Logger: ...
def setup_logger(debug: bool, color: bool) -> None: ...

class Formatter(logging.Formatter):
    color: bool
    debug: bool
    def __init__(self, debug: bool = False, color: bool = False) -> None: ...

class Handler(logging.StreamHandler[TextIO]):
    color: bool
    debug: bool
    def __init__(self, log_level: logging._Level, debug: bool = False, color: bool = False) -> None: ...



# pyright: reportInvalidStubStatement=none

import sys
from _typeshed import StrPath, SupportsKeysAndGetItem, SupportsWrite
from argparse import Namespace
from collections.abc import Callable, Iterable, Sequence
from logging import Logger
from typing import Any, Protocol, TypeVar
from typing_extensions import ParamSpec, TypeAlias

import flask
from flask_sqlalchemy import SQLAlchemy

_T = TypeVar("_T")
_T_contra = TypeVar("_T_contra", contravariant=True)
_P = ParamSpec("_P")
_ConfigureCallback: TypeAlias = Callable[[Config], Config]
_AlembicConfigValue: TypeAlias = Any

alembic_version: tuple[int, int, int]
log: Logger

# TODO: Use _typeshed.SupportsFlush when it's available in type checkers.
class _SupportsWriteAndFlush(SupportsWrite[_T_contra], Protocol):
    def flush(self) -> object: ...

class Config:  # should inherit from alembic.config.Config which is not possible yet
    template_directory: str | None
    # Same as alembic.config.Config + template_directory kwarg
    def __init__(
        self,
        file_: StrPath | None = None,
        ini_section: str = "alembic",
        # Same as buffer argument in TextIOWrapper.__init__.buffer
        output_buffer: _SupportsWriteAndFlush[str] | None = None,
        # Same as stream argument in alembic.util.messaging
        stdout: SupportsWrite[str] = sys.stdout,
        cmd_opts: Namespace | None = None,
        config_args: SupportsKeysAndGetItem[str, _AlembicConfigValue] | Iterable[tuple[str, _AlembicConfigValue]] = ...,
        attributes: (
            SupportsKeysAndGetItem[_AlembicConfigValue, _AlembicConfigValue]
            | Iterable[tuple[_AlembicConfigValue, _AlembicConfigValue]]
            | None
        ) = None,
        *,
        template_directory: str | None = None,
    ) -> None: ...
    def get_template_directory(self) -> str: ...

class Migrate:
    configure_callbacks: list[_ConfigureCallback]
    db: SQLAlchemy | None
    directory: str
    alembic_ctx_kwargs: dict[str, _AlembicConfigValue]
    def __init__(
        self,
        app: flask.Flask | None = None,
        db: SQLAlchemy | None = None,
        directory: str = "migrations",
        command: str = "db",
        compare_type: bool = True,
        render_as_batch: bool = True,
        **kwargs: _AlembicConfigValue,
    ) -> None: ...
    def init_app(
        self,
        app: flask.Flask,
        db: SQLAlchemy | None = None,
        directory: str | None = None,
        command: str | None = None,
        compare_type: bool | None = None,
        render_as_batch: bool | None = None,
        **kwargs: _AlembicConfigValue,
    ) -> None: ...
    def configure(self, f: _ConfigureCallback) -> _ConfigureCallback: ...
    def call_configure_callbacks(self, config: Config) -> Config: ...
    def get_config(
        self, directory: str | None = None, x_arg: str | Sequence[str] | None = None, opts: Iterable[str] | None = None
    ) -> Config: ...

def catch_errors(f: Callable[_P, _T]) -> Callable[_P, _T]: ...
def list_templates() -> None: ...
def init(directory: str | None = None, multidb: bool = False, template: str | None = None, package: bool = False) -> None: ...
def revision(
    directory: str | None = None,
    message: str | None = None,
    autogenerate: bool = False,
    sql: bool = False,
    head: str = "head",
    splice: bool = False,
    branch_label: str | None = None,
    version_path: str | None = None,
    rev_id: str | None = None,
) -> None: ...
def migrate(
    directory: str | None = None,
    message: str | None = None,
    sql: bool = False,
    head: str = "head",
    splice: bool = False,
    branch_label: str | None = None,
    version_path: str | None = None,
    rev_id: str | None = None,
    x_arg: str | Sequence[str] | None = None,
) -> None: ...
def edit(directory: str | None = None, revision: str = "current") -> None: ...
def merge(
    directory: str | None = None,
    revisions: str = "",
    message: str | None = None,
    branch_label: str | None = None,
    rev_id: str | None = None,
) -> None: ...
def upgrade(
    directory: str | None = None,
    revision: str = "head",
    sql: bool = False,
    tag: str | None = None,
    x_arg: str | Sequence[str] | None = None,
) -> None: ...
def downgrade(
    directory: str | None = None,
    revision: str = "-1",
    sql: bool = False,
    tag: str | None = None,
    x_arg: str | Sequence[str] | None = None,
) -> None: ...
def show(directory: str | None = None, revision: str = "head") -> None: ...
def history(
    directory: str | None = None, rev_range: str | None = None, verbose: bool = False, indicate_current: bool = False
) -> None: ...
def heads(directory: str | None = None, verbose: bool = False, resolve_dependencies: bool = False) -> None: ...
def branches(directory: str | None = None, verbose: bool = False) -> None: ...
def current(directory: str | None = None, verbose: bool = False) -> None: ...
def stamp(
    directory: str | None = None, revision: str = "head", sql: bool = False, tag: str | None = None, purge: bool = False
) -> None: ...
def check(directory: str | None = None) -> None: ...



from typing import Any

from . import MQTTException as MQTTException

class MalformedPacket(MQTTException): ...

def writeInt16(length: int) -> bytearray: ...
def readInt16(buf: bytes) -> int: ...
def writeInt32(length: int) -> bytearray: ...
def readInt32(buf: bytes) -> int: ...
def writeUTF(data: str | bytes) -> bytearray: ...
def readUTF(buffer: bytes, maxlen: int) -> tuple[str, int]: ...
def writeBytes(buffer: bytes) -> bytearray: ...
def readBytes(buffer: bytes) -> tuple[bytes, int]: ...

class VariableByteIntegers:
    @staticmethod
    def encode(x: int) -> bytes: ...
    @staticmethod
    def decode(buffer: bytes) -> tuple[int, int]: ...

class Properties:
    packetType: int
    types: list[str]
    names: dict[str, int]
    properties: dict[int, tuple[int, list[int]]]
    def __init__(self, packetType: int) -> None: ...
    def allowsMultiple(self, compressedName: str) -> bool: ...
    def getIdentFromName(self, compressedName: str) -> int: ...
    def __setattr__(self, name: str, value: Any) -> None: ...
    def json(self) -> dict[str, Any]: ...
    def isEmpty(self) -> bool: ...
    def clear(self) -> None: ...
    def writeProperty(self, identifier: int, type: int, value: Any) -> bytes: ...
    def pack(self) -> bytes: ...
    def readProperty(self, buffer: bytes, type: int, propslen: int) -> Any: ...
    def getNameFromIdent(self, identifier: int) -> str | None: ...
    def unpack(self, buffer: bytes) -> tuple[Properties, int]: ...



from collections.abc import Mapping
from typing import Any, Literal, TypedDict
from typing_extensions import NotRequired

from oauthlib.common import Request
from oauthlib.oauth2.rfc6749.clients import Client

class _BearerToken(TypedDict):
    token_type: Literal["Bearer"]
    access_token: str
    expires_in: int
    scope: NotRequired[str]
    refresh_token: NotRequired[str]
    state: NotRequired[str]

class _AuthorizationCode(TypedDict):
    code: str
    state: NotRequired[str]
    nonce: NotRequired[str]

log: Any

class RequestValidator:
    def client_authentication_required(self, request: Request, *args, **kwargs) -> bool: ...
    def authenticate_client(self, request: Request, *args, **kwargs) -> bool: ...
    def authenticate_client_id(self, client_id: str, request: Request, *args, **kwargs) -> bool: ...
    def confirm_redirect_uri(
        self, client_id: str, code: str, redirect_uri: str, client: Client, request: Request, *args, **kwargs
    ) -> bool: ...
    def get_default_redirect_uri(self, client_id: str, request: Request, *args, **kwargs) -> str: ...
    def get_default_scopes(self, client_id: str, request: Request, *args, **kwargs) -> list[str]: ...
    def get_original_scopes(self, refresh_token: str, request: Request, *args, **kwargs) -> list[str]: ...
    def is_within_original_scope(
        self, request_scopes: list[str], refresh_token: str, request: Request, *args, **kwargs
    ) -> bool: ...
    def introspect_token(
        self, token: str, token_type_hint: str, request: Request, *args, **kwargs
    ) -> dict[str, int | str | list[str]] | None: ...
    def invalidate_authorization_code(self, client_id: str, code: str, request: Request, *args, **kwargs) -> None: ...
    def revoke_token(self, token: str, token_type_hint: str, request: Request, *args, **kwargs) -> None: ...
    def rotate_refresh_token(self, request: Request) -> bool: ...
    def save_authorization_code(self, client_id: str, code: _AuthorizationCode, request: Request, *args, **kwargs) -> None: ...
    def save_token(self, token: Mapping[str, object], request: Request, *args, **kwargs) -> object: ...
    def save_bearer_token(self, token: _BearerToken, request: Request, *args, **kwargs) -> object: ...
    def validate_bearer_token(self, token: str, scopes: list[str], request: Request) -> bool: ...
    def validate_client_id(self, client_id: str, request: Request, *args, **kwargs) -> bool: ...
    def validate_code(self, client_id: str, code: str, client: Client, request: Request, *args, **kwargs) -> bool: ...
    def validate_grant_type(self, client_id: str, grant_type: str, client: Client, request: Request, *args, **kwargs) -> bool: ...
    def validate_redirect_uri(self, client_id: str, redirect_uri: str, request: Request, *args, **kwargs) -> bool: ...
    def validate_refresh_token(self, refresh_token: str, client: Client, request: Request, *args, **kwargs) -> bool: ...
    def validate_response_type(
        self, client_id: str, response_type: str, client: Client, request: Request, *args, **kwargs
    ) -> bool: ...
    def validate_scopes(self, client_id: str, scopes: list[str], client: Client, request: Request, *args, **kwargs) -> bool: ...
    def validate_user(self, username: str, password: str, client: Client, request: Request, *args, **kwargs) -> bool: ...
    def is_pkce_required(self, client_id: str, request: Request) -> bool: ...
    def get_code_challenge(self, code: str, request: Request) -> str: ...
    def get_code_challenge_method(self, code: str, request: Request) -> str: ...



from _typeshed import Incomplete
from abc import ABCMeta
from collections.abc import Mapping
from typing import Any

class Trie(Mapping[Any, Any], metaclass=ABCMeta):
    def keys(self, prefix: Incomplete | None = None): ...
    def has_keys_with_prefix(self, prefix): ...
    def longest_prefix(self, prefix): ...
    def longest_prefix_item(self, prefix): ...



from _typeshed import Unused
from collections.abc import Callable
from typing import Any, Final
from typing_extensions import TypeAlias

from Xlib._typing import ErrorHandler
from Xlib.display import Display
from Xlib.protocol import rq
from Xlib.xobject import drawable, resource

_Update: TypeAlias = Callable[[rq.DictWrapper | dict[str, Any]], object]

extname: Final = "Composite"
RedirectAutomatic: Final = 0
RedirectManual: Final = 1

class QueryVersion(rq.ReplyRequest): ...

def query_version(self: Display | resource.Resource) -> QueryVersion: ...

class RedirectWindow(rq.Request): ...

def redirect_window(self: drawable.Window, update: _Update, onerror: ErrorHandler[object] | None = None) -> None: ...

class RedirectSubwindows(rq.Request): ...

def redirect_subwindows(self: drawable.Window, update: _Update, onerror: ErrorHandler[object] | None = None) -> None: ...

class UnredirectWindow(rq.Request): ...

def unredirect_window(self: drawable.Window, update: _Update, onerror: ErrorHandler[object] | None = None) -> None: ...

class UnredirectSubindows(rq.Request): ...

def unredirect_subwindows(self: drawable.Window, update: _Update, onerror: ErrorHandler[object] | None = None) -> None: ...

class CreateRegionFromBorderClip(rq.Request): ...

def create_region_from_border_clip(self: drawable.Window, onerror: ErrorHandler[object] | None = None) -> int: ...

class NameWindowPixmap(rq.Request): ...

def name_window_pixmap(self: Display | resource.Resource, onerror: ErrorHandler[object] | None = None) -> drawable.Pixmap: ...

class GetOverlayWindow(rq.ReplyRequest): ...

def get_overlay_window(self: Display) -> GetOverlayWindow: ...
def init(disp: Display, info: Unused) -> None: ...



from _typeshed import Incomplete

PET_DISCRETEVALUE: int
PET_RANGEDVALUE: int
PET_DEFAULTVALUE: int
PET_ENDRANGE: int
PDTF_DEFAULT: int
PDTF_MULTIPLEVALUES: int
PDTF_ISINNATE: int
PDTF_ISGROUP: int
PDTF_CANGROUPBY: int
PDTF_CANSTACKBY: int
PDTF_ISTREEPROPERTY: int
PDTF_INCLUDEINFULLTEXTQUERY: int
PDTF_ISVIEWABLE: int
PDTF_ISQUERYABLE: int
PDTF_ISSYSTEMPROPERTY: int
PDTF_MASK_ALL: int
PDVF_DEFAULT: int
PDVF_CENTERALIGN: int
PDVF_RIGHTALIGN: int
PDVF_BEGINNEWGROUP: int
PDVF_FILLAREA: int
PDVF_SORTDESCENDING: int
PDVF_SHOWONLYIFPRESENT: int
PDVF_SHOWBYDEFAULT: int
PDVF_SHOWINPRIMARYLIST: int
PDVF_SHOWINSECONDARYLIST: int
PDVF_HIDELABEL: int
PDVF_HIDDEN: int
PDVF_CANWRAP: int
PDVF_MASK_ALL: int
PDDT_STRING: int
PDDT_NUMBER: int
PDDT_BOOLEAN: int
PDDT_DATETIME: int
PDDT_ENUMERATED: int
PDGR_DISCRETE: int
PDGR_ALPHANUMERIC: int
PDGR_SIZE: int
PDGR_DYNAMIC: int
PDGR_DATE: int
PDGR_PERCENT: int
PDGR_ENUMERATED: int
PDFF_DEFAULT: int
PDFF_PREFIXNAME: int
PDFF_FILENAME: int
PDFF_ALWAYSKB: int
PDFF_RESERVED_RIGHTTOLEFT: int
PDFF_SHORTTIME: int
PDFF_LONGTIME: int
PDFF_HIDETIME: int
PDFF_SHORTDATE: int
PDFF_LONGDATE: int
PDFF_HIDEDATE: int
PDFF_RELATIVEDATE: int
PDFF_USEEDITINVITATION: int
PDFF_READONLY: int
PDFF_NOAUTOREADINGORDER: int
PDSD_GENERAL: int
PDSD_A_Z: int
PDSD_LOWEST_HIGHEST: int
PDSD_SMALLEST_BIGGEST: int
PDSD_OLDEST_NEWEST: int
PDRDT_GENERAL: int
PDRDT_DATE: int
PDRDT_SIZE: int
PDRDT_COUNT: int
PDRDT_REVISION: int
PDRDT_LENGTH: int
PDRDT_DURATION: int
PDRDT_SPEED: int
PDRDT_RATE: int
PDRDT_RATING: int
PDRDT_PRIORITY: int
PDAT_DEFAULT: int
PDAT_FIRST: int
PDAT_SUM: int
PDAT_AVERAGE: int
PDAT_DATERANGE: int
PDAT_UNION: int
PDAT_MAX: int
PDAT_MIN: int
PDCOT_NONE: int
PDCOT_STRING: int
PDCOT_SIZE: int
PDCOT_DATETIME: int
PDCOT_BOOLEAN: int
PDCOT_NUMBER: int
PDSIF_DEFAULT: int
PDSIF_ININVERTEDINDEX: int
PDSIF_ISCOLUMN: int
PDSIF_ISCOLUMNSPARSE: int
PDCIT_NONE: int
PDCIT_ONDISK: int
PDCIT_INMEMORY: int
PDEF_ALL: int
PDEF_SYSTEM: int
PDEF_NONSYSTEM: int
PDEF_VIEWABLE: int
PDEF_QUERYABLE: int
PDEF_INFULLTEXTQUERY: int
PDEF_COLUMN: int
PSC_NORMAL: int
PSC_NOTINSOURCE: int
PSC_DIRTY: int
COP_IMPLICIT: int
COP_EQUAL: int
COP_NOTEQUAL: int
COP_LESSTHAN: int
COP_GREATERTHAN: int
COP_LESSTHANOREQUAL: int
COP_GREATERTHANOREQUAL: int
COP_VALUE_STARTSWITH: int
COP_VALUE_ENDSWITH: int
COP_VALUE_CONTAINS: int
COP_VALUE_NOTCONTAINS: int
COP_DOSWILDCARDS: int
COP_WORD_EQUAL: int
COP_WORD_STARTSWITH: int
COP_APPLICATION_SPECIFIC: int
FPSPS_READONLY: int
PKEY_PIDSTR_MAX: int
GUIDSTRING_MAX: Incomplete
PKEYSTR_MAX: Incomplete
PKEY_Audio_ChannelCount: Incomplete
PKEY_Audio_Compression: Incomplete
PKEY_Audio_EncodingBitrate: Incomplete
PKEY_Audio_Format: Incomplete
PKEY_Audio_IsVariableBitRate: Incomplete
PKEY_Audio_PeakValue: Incomplete
PKEY_Audio_SampleRate: Incomplete
PKEY_Audio_SampleSize: Incomplete
PKEY_Audio_StreamName: Incomplete
PKEY_Audio_StreamNumber: Incomplete
PKEY_Calendar_Duration: Incomplete
PKEY_Calendar_IsOnline: Incomplete
PKEY_Calendar_IsRecurring: Incomplete
PKEY_Calendar_Location: Incomplete
PKEY_Calendar_OptionalAttendeeAddresses: Incomplete
PKEY_Calendar_OptionalAttendeeNames: Incomplete
PKEY_Calendar_OrganizerAddress: Incomplete
PKEY_Calendar_OrganizerName: Incomplete
PKEY_Calendar_ReminderTime: Incomplete
PKEY_Calendar_RequiredAttendeeAddresses: Incomplete
PKEY_Calendar_RequiredAttendeeNames: Incomplete
PKEY_Calendar_Resources: Incomplete
PKEY_Calendar_ShowTimeAs: Incomplete
PKEY_Calendar_ShowTimeAsText: Incomplete
PKEY_Communication_AccountName: Incomplete
PKEY_Communication_Suffix: Incomplete
PKEY_Communication_TaskStatus: Incomplete
PKEY_Communication_TaskStatusText: Incomplete
PKEY_Computer_DecoratedFreeSpace: Incomplete
PKEY_Contact_Anniversary: Incomplete
PKEY_Contact_AssistantName: Incomplete
PKEY_Contact_AssistantTelephone: Incomplete
PKEY_Contact_Birthday: Incomplete
PKEY_Contact_BusinessAddress: Incomplete
PKEY_Contact_BusinessAddressCity: Incomplete
PKEY_Contact_BusinessAddressCountry: Incomplete
PKEY_Contact_BusinessAddressPostalCode: Incomplete
PKEY_Contact_BusinessAddressPostOfficeBox: Incomplete
PKEY_Contact_BusinessAddressState: Incomplete
PKEY_Contact_BusinessAddressStreet: Incomplete
PKEY_Contact_BusinessFaxNumber: Incomplete
PKEY_Contact_BusinessHomePage: Incomplete
PKEY_Contact_BusinessTelephone: Incomplete
PKEY_Contact_CallbackTelephone: Incomplete
PKEY_Contact_CarTelephone: Incomplete
PKEY_Contact_Children: Incomplete
PKEY_Contact_CompanyMainTelephone: Incomplete
PKEY_Contact_Department: Incomplete
PKEY_Contact_EmailAddress: Incomplete
PKEY_Contact_EmailAddress2: Incomplete
PKEY_Contact_EmailAddress3: Incomplete
PKEY_Contact_EmailAddresses: Incomplete
PKEY_Contact_EmailName: Incomplete
PKEY_Contact_FileAsName: Incomplete
PKEY_Contact_FirstName: Incomplete
PKEY_Contact_FullName: Incomplete
PKEY_Contact_Gender: Incomplete
PKEY_Contact_Hobbies: Incomplete
PKEY_Contact_HomeAddress: Incomplete
PKEY_Contact_HomeAddressCity: Incomplete
PKEY_Contact_HomeAddressCountry: Incomplete
PKEY_Contact_HomeAddressPostalCode: Incomplete
PKEY_Contact_HomeAddressPostOfficeBox: Incomplete
PKEY_Contact_HomeAddressState: Incomplete
PKEY_Contact_HomeAddressStreet: Incomplete
PKEY_Contact_HomeFaxNumber: Incomplete
PKEY_Contact_HomeTelephone: Incomplete
PKEY_Contact_IMAddress: Incomplete
PKEY_Contact_Initials: Incomplete
PKEY_Contact_JA_CompanyNamePhonetic: Incomplete
PKEY_Contact_JA_FirstNamePhonetic: Incomplete
PKEY_Contact_JA_LastNamePhonetic: Incomplete
PKEY_Contact_JobTitle: Incomplete
PKEY_Contact_Label: Incomplete
PKEY_Contact_LastName: Incomplete
PKEY_Contact_MailingAddress: Incomplete
PKEY_Contact_MiddleName: Incomplete
PKEY_Contact_MobileTelephone: Incomplete
PKEY_Contact_NickName: Incomplete
PKEY_Contact_OfficeLocation: Incomplete
PKEY_Contact_OtherAddress: Incomplete
PKEY_Contact_OtherAddressCity: Incomplete
PKEY_Contact_OtherAddressCountry: Incomplete
PKEY_Contact_OtherAddressPostalCode: Incomplete
PKEY_Contact_OtherAddressPostOfficeBox: Incomplete
PKEY_Contact_OtherAddressState: Incomplete
PKEY_Contact_OtherAddressStreet: Incomplete
PKEY_Contact_PagerTelephone: Incomplete
PKEY_Contact_PersonalTitle: Incomplete
PKEY_Contact_PrimaryAddressCity: Incomplete
PKEY_Contact_PrimaryAddressCountry: Incomplete
PKEY_Contact_PrimaryAddressPostalCode: Incomplete
PKEY_Contact_PrimaryAddressPostOfficeBox: Incomplete
PKEY_Contact_PrimaryAddressState: Incomplete
PKEY_Contact_PrimaryAddressStreet: Incomplete
PKEY_Contact_PrimaryEmailAddress: Incomplete
PKEY_Contact_PrimaryTelephone: Incomplete
PKEY_Contact_Profession: Incomplete
PKEY_Contact_SpouseName: Incomplete
PKEY_Contact_Suffix: Incomplete
PKEY_Contact_TelexNumber: Incomplete
PKEY_Contact_TTYTDDTelephone: Incomplete
PKEY_Contact_WebPage: Incomplete
PKEY_AcquisitionID: Incomplete
PKEY_ApplicationName: Incomplete
PKEY_Author: Incomplete
PKEY_Capacity: Incomplete
PKEY_Category: Incomplete
PKEY_Comment: Incomplete
PKEY_Company: Incomplete
PKEY_ComputerName: Incomplete
PKEY_ContainedItems: Incomplete
PKEY_ContentStatus: Incomplete
PKEY_ContentType: Incomplete
PKEY_Copyright: Incomplete
PKEY_DateAccessed: Incomplete
PKEY_DateAcquired: Incomplete
PKEY_DateArchived: Incomplete
PKEY_DateCompleted: Incomplete
PKEY_DateCreated: Incomplete
PKEY_DateImported: Incomplete
PKEY_DateModified: Incomplete
PKEY_DueDate: Incomplete
PKEY_EndDate: Incomplete
PKEY_FileAllocationSize: Incomplete
PKEY_FileAttributes: Incomplete
PKEY_FileCount: Incomplete
PKEY_FileDescription: Incomplete
PKEY_FileExtension: Incomplete
PKEY_FileFRN: Incomplete
PKEY_FileName: Incomplete
PKEY_FileOwner: Incomplete
PKEY_FileVersion: Incomplete
PKEY_FindData: Incomplete
PKEY_FlagColor: Incomplete
PKEY_FlagColorText: Incomplete
PKEY_FlagStatus: Incomplete
PKEY_FlagStatusText: Incomplete
PKEY_FreeSpace: Incomplete
PKEY_Identity: Incomplete
PKEY_Importance: Incomplete
PKEY_ImportanceText: Incomplete
PKEY_IsAttachment: Incomplete
PKEY_IsDeleted: Incomplete
PKEY_IsFlagged: Incomplete
PKEY_IsFlaggedComplete: Incomplete
PKEY_IsIncomplete: Incomplete
PKEY_IsRead: Incomplete
PKEY_IsSendToTarget: Incomplete
PKEY_IsShared: Incomplete
PKEY_ItemAuthors: Incomplete
PKEY_ItemDate: Incomplete
PKEY_ItemFolderNameDisplay: Incomplete
PKEY_ItemFolderPathDisplay: Incomplete
PKEY_ItemFolderPathDisplayNarrow: Incomplete
PKEY_ItemName: Incomplete
PKEY_ItemNameDisplay: Incomplete
PKEY_ItemNamePrefix: Incomplete
PKEY_ItemParticipants: Incomplete
PKEY_ItemPathDisplay: Incomplete
PKEY_ItemPathDisplayNarrow: Incomplete
PKEY_ItemType: Incomplete
PKEY_ItemTypeText: Incomplete
PKEY_ItemUrl: Incomplete
PKEY_Keywords: Incomplete
PKEY_Kind: Incomplete
PKEY_KindText: Incomplete
PKEY_Language: Incomplete
PKEY_MileageInformation: Incomplete
PKEY_MIMEType: Incomplete
PKEY_Null: Incomplete
PKEY_OfflineAvailability: Incomplete
PKEY_OfflineStatus: Incomplete
PKEY_OriginalFileName: Incomplete
PKEY_ParentalRating: Incomplete
PKEY_ParentalRatingReason: Incomplete
PKEY_ParentalRatingsOrganization: Incomplete
PKEY_ParsingBindContext: Incomplete
PKEY_ParsingName: Incomplete
PKEY_ParsingPath: Incomplete
PKEY_PerceivedType: Incomplete
PKEY_PercentFull: Incomplete
PKEY_Priority: Incomplete
PKEY_PriorityText: Incomplete
PKEY_Project: Incomplete
PKEY_ProviderItemID: Incomplete
PKEY_Rating: Incomplete
PKEY_RatingText: Incomplete
PKEY_Sensitivity: Incomplete
PKEY_SensitivityText: Incomplete
PKEY_SFGAOFlags: Incomplete
PKEY_SharedWith: Incomplete
PKEY_ShareUserRating: Incomplete
PKEY_Shell_OmitFromView: Incomplete
PKEY_SimpleRating: Incomplete
PKEY_Size: Incomplete
PKEY_SoftwareUsed: Incomplete
PKEY_SourceItem: Incomplete
PKEY_StartDate: Incomplete
PKEY_Status: Incomplete
PKEY_Subject: Incomplete
PKEY_Thumbnail: Incomplete
PKEY_ThumbnailCacheId: Incomplete
PKEY_ThumbnailStream: Incomplete
PKEY_Title: Incomplete
PKEY_TotalFileSize: Incomplete
PKEY_Trademarks: Incomplete
PKEY_Document_ByteCount: Incomplete
PKEY_Document_CharacterCount: Incomplete
PKEY_Document_ClientID: Incomplete
PKEY_Document_Contributor: Incomplete
PKEY_Document_DateCreated: Incomplete
PKEY_Document_DatePrinted: Incomplete
PKEY_Document_DateSaved: Incomplete
PKEY_Document_Division: Incomplete
PKEY_Document_DocumentID: Incomplete
PKEY_Document_HiddenSlideCount: Incomplete
PKEY_Document_LastAuthor: Incomplete
PKEY_Document_LineCount: Incomplete
PKEY_Document_Manager: Incomplete
PKEY_Document_MultimediaClipCount: Incomplete
PKEY_Document_NoteCount: Incomplete
PKEY_Document_PageCount: Incomplete
PKEY_Document_ParagraphCount: Incomplete
PKEY_Document_PresentationFormat: Incomplete
PKEY_Document_RevisionNumber: Incomplete
PKEY_Document_Security: Incomplete
PKEY_Document_SlideCount: Incomplete
PKEY_Document_Template: Incomplete
PKEY_Document_TotalEditingTime: Incomplete
PKEY_Document_Version: Incomplete
PKEY_Document_WordCount: Incomplete
PKEY_DRM_DatePlayExpires: Incomplete
PKEY_DRM_DatePlayStarts: Incomplete
PKEY_DRM_Description: Incomplete
PKEY_DRM_IsProtected: Incomplete
PKEY_DRM_PlayCount: Incomplete
PKEY_GPS_Altitude: Incomplete
PKEY_GPS_AltitudeDenominator: Incomplete
PKEY_GPS_AltitudeNumerator: Incomplete
PKEY_GPS_AltitudeRef: Incomplete
PKEY_GPS_AreaInformation: Incomplete
PKEY_GPS_Date: Incomplete
PKEY_GPS_DestBearing: Incomplete
PKEY_GPS_DestBearingDenominator: Incomplete
PKEY_GPS_DestBearingNumerator: Incomplete
PKEY_GPS_DestBearingRef: Incomplete
PKEY_GPS_DestDistance: Incomplete
PKEY_GPS_DestDistanceDenominator: Incomplete
PKEY_GPS_DestDistanceNumerator: Incomplete
PKEY_GPS_DestDistanceRef: Incomplete
PKEY_GPS_DestLatitude: Incomplete
PKEY_GPS_DestLatitudeDenominator: Incomplete
PKEY_GPS_DestLatitudeNumerator: Incomplete
PKEY_GPS_DestLatitudeRef: Incomplete
PKEY_GPS_DestLongitude: Incomplete
PKEY_GPS_DestLongitudeDenominator: Incomplete
PKEY_GPS_DestLongitudeNumerator: Incomplete
PKEY_GPS_DestLongitudeRef: Incomplete
PKEY_GPS_Differential: Incomplete
PKEY_GPS_DOP: Incomplete
PKEY_GPS_DOPDenominator: Incomplete
PKEY_GPS_DOPNumerator: Incomplete
PKEY_GPS_ImgDirection: Incomplete
PKEY_GPS_ImgDirectionDenominator: Incomplete
PKEY_GPS_ImgDirectionNumerator: Incomplete
PKEY_GPS_ImgDirectionRef: Incomplete
PKEY_GPS_Latitude: Incomplete
PKEY_GPS_LatitudeDenominator: Incomplete
PKEY_GPS_LatitudeNumerator: Incomplete
PKEY_GPS_LatitudeRef: Incomplete
PKEY_GPS_Longitude: Incomplete
PKEY_GPS_LongitudeDenominator: Incomplete
PKEY_GPS_LongitudeNumerator: Incomplete
PKEY_GPS_LongitudeRef: Incomplete
PKEY_GPS_MapDatum: Incomplete
PKEY_GPS_MeasureMode: Incomplete
PKEY_GPS_ProcessingMethod: Incomplete
PKEY_GPS_Satellites: Incomplete
PKEY_GPS_Speed: Incomplete
PKEY_GPS_SpeedDenominator: Incomplete
PKEY_GPS_SpeedNumerator: Incomplete
PKEY_GPS_SpeedRef: Incomplete
PKEY_GPS_Status: Incomplete
PKEY_GPS_Track: Incomplete
PKEY_GPS_TrackDenominator: Incomplete
PKEY_GPS_TrackNumerator: Incomplete
PKEY_GPS_TrackRef: Incomplete
PKEY_GPS_VersionID: Incomplete
PKEY_Image_BitDepth: Incomplete
PKEY_Image_ColorSpace: Incomplete
PKEY_Image_CompressedBitsPerPixel: Incomplete
PKEY_Image_CompressedBitsPerPixelDenominator: Incomplete
PKEY_Image_CompressedBitsPerPixelNumerator: Incomplete
PKEY_Image_Compression: Incomplete
PKEY_Image_CompressionText: Incomplete
PKEY_Image_Dimensions: Incomplete
PKEY_Image_HorizontalResolution: Incomplete
PKEY_Image_HorizontalSize: Incomplete
PKEY_Image_ImageID: Incomplete
PKEY_Image_ResolutionUnit: Incomplete
PKEY_Image_VerticalResolution: Incomplete
PKEY_Image_VerticalSize: Incomplete
PKEY_Journal_Contacts: Incomplete
PKEY_Journal_EntryType: Incomplete
PKEY_Link_Comment: Incomplete
PKEY_Link_DateVisited: Incomplete
PKEY_Link_Description: Incomplete
PKEY_Link_Status: Incomplete
PKEY_Link_TargetExtension: Incomplete
PKEY_Link_TargetParsingPath: Incomplete
PKEY_Link_TargetSFGAOFlags: Incomplete
PKEY_Media_AuthorUrl: Incomplete
PKEY_Media_AverageLevel: Incomplete
PKEY_Media_ClassPrimaryID: Incomplete
PKEY_Media_ClassSecondaryID: Incomplete
PKEY_Media_CollectionGroupID: Incomplete
PKEY_Media_CollectionID: Incomplete
PKEY_Media_ContentDistributor: Incomplete
PKEY_Media_ContentID: Incomplete
PKEY_Media_CreatorApplication: Incomplete
PKEY_Media_CreatorApplicationVersion: Incomplete
PKEY_Media_DateEncoded: Incomplete
PKEY_Media_DateReleased: Incomplete
PKEY_Media_Duration: Incomplete
PKEY_Media_DVDID: Incomplete
PKEY_Media_EncodedBy: Incomplete
PKEY_Media_EncodingSettings: Incomplete
PKEY_Media_FrameCount: Incomplete
PKEY_Media_MCDI: Incomplete
PKEY_Media_MetadataContentProvider: Incomplete
PKEY_Media_Producer: Incomplete
PKEY_Media_PromotionUrl: Incomplete
PKEY_Media_ProtectionType: Incomplete
PKEY_Media_ProviderRating: Incomplete
PKEY_Media_ProviderStyle: Incomplete
PKEY_Media_Publisher: Incomplete
PKEY_Media_SubscriptionContentId: Incomplete
PKEY_Media_SubTitle: Incomplete
PKEY_Media_UniqueFileIdentifier: Incomplete
PKEY_Media_UserNoAutoInfo: Incomplete
PKEY_Media_UserWebUrl: Incomplete
PKEY_Media_Writer: Incomplete
PKEY_Media_Year: Incomplete
PKEY_Message_AttachmentContents: Incomplete
PKEY_Message_AttachmentNames: Incomplete
PKEY_Message_BccAddress: Incomplete
PKEY_Message_BccName: Incomplete
PKEY_Message_CcAddress: Incomplete
PKEY_Message_CcName: Incomplete
PKEY_Message_ConversationID: Incomplete
PKEY_Message_ConversationIndex: Incomplete
PKEY_Message_DateReceived: Incomplete
PKEY_Message_DateSent: Incomplete
PKEY_Message_FromAddress: Incomplete
PKEY_Message_FromName: Incomplete
PKEY_Message_HasAttachments: Incomplete
PKEY_Message_IsFwdOrReply: Incomplete
PKEY_Message_MessageClass: Incomplete
PKEY_Message_SenderAddress: Incomplete
PKEY_Message_SenderName: Incomplete
PKEY_Message_Store: Incomplete
PKEY_Message_ToAddress: Incomplete
PKEY_Message_ToDoTitle: Incomplete
PKEY_Message_ToName: Incomplete
PKEY_Music_AlbumArtist: Incomplete
PKEY_Music_AlbumTitle: Incomplete
PKEY_Music_Artist: Incomplete
PKEY_Music_BeatsPerMinute: Incomplete
PKEY_Music_Composer: Incomplete
PKEY_Music_Conductor: Incomplete
PKEY_Music_ContentGroupDescription: Incomplete
PKEY_Music_Genre: Incomplete
PKEY_Music_InitialKey: Incomplete
PKEY_Music_Lyrics: Incomplete
PKEY_Music_Mood: Incomplete
PKEY_Music_PartOfSet: Incomplete
PKEY_Music_Period: Incomplete
PKEY_Music_SynchronizedLyrics: Incomplete
PKEY_Music_TrackNumber: Incomplete
PKEY_Note_Color: Incomplete
PKEY_Note_ColorText: Incomplete
PKEY_Photo_Aperture: Incomplete
PKEY_Photo_ApertureDenominator: Incomplete
PKEY_Photo_ApertureNumerator: Incomplete
PKEY_Photo_Brightness: Incomplete
PKEY_Photo_BrightnessDenominator: Incomplete
PKEY_Photo_BrightnessNumerator: Incomplete
PKEY_Photo_CameraManufacturer: Incomplete
PKEY_Photo_CameraModel: Incomplete
PKEY_Photo_CameraSerialNumber: Incomplete
PKEY_Photo_Contrast: Incomplete
PKEY_Photo_ContrastText: Incomplete
PKEY_Photo_DateTaken: Incomplete
PKEY_Photo_DigitalZoom: Incomplete
PKEY_Photo_DigitalZoomDenominator: Incomplete
PKEY_Photo_DigitalZoomNumerator: Incomplete
PKEY_Photo_Event: Incomplete
PKEY_Photo_EXIFVersion: Incomplete
PKEY_Photo_ExposureBias: Incomplete
PKEY_Photo_ExposureBiasDenominator: Incomplete
PKEY_Photo_ExposureBiasNumerator: Incomplete
PKEY_Photo_ExposureIndex: Incomplete
PKEY_Photo_ExposureIndexDenominator: Incomplete
PKEY_Photo_ExposureIndexNumerator: Incomplete
PKEY_Photo_ExposureProgram: Incomplete
PKEY_Photo_ExposureProgramText: Incomplete
PKEY_Photo_ExposureTime: Incomplete
PKEY_Photo_ExposureTimeDenominator: Incomplete
PKEY_Photo_ExposureTimeNumerator: Incomplete
PKEY_Photo_Flash: Incomplete
PKEY_Photo_FlashEnergy: Incomplete
PKEY_Photo_FlashEnergyDenominator: Incomplete
PKEY_Photo_FlashEnergyNumerator: Incomplete
PKEY_Photo_FlashManufacturer: Incomplete
PKEY_Photo_FlashModel: Incomplete
PKEY_Photo_FlashText: Incomplete
PKEY_Photo_FNumber: Incomplete
PKEY_Photo_FNumberDenominator: Incomplete
PKEY_Photo_FNumberNumerator: Incomplete
PKEY_Photo_FocalLength: Incomplete
PKEY_Photo_FocalLengthDenominator: Incomplete
PKEY_Photo_FocalLengthInFilm: Incomplete
PKEY_Photo_FocalLengthNumerator: Incomplete
PKEY_Photo_FocalPlaneXResolution: Incomplete
PKEY_Photo_FocalPlaneXResolutionDenominator: Incomplete
PKEY_Photo_FocalPlaneXResolutionNumerator: Incomplete
PKEY_Photo_FocalPlaneYResolution: Incomplete
PKEY_Photo_FocalPlaneYResolutionDenominator: Incomplete
PKEY_Photo_FocalPlaneYResolutionNumerator: Incomplete
PKEY_Photo_GainControl: Incomplete
PKEY_Photo_GainControlDenominator: Incomplete
PKEY_Photo_GainControlNumerator: Incomplete
PKEY_Photo_GainControlText: Incomplete
PKEY_Photo_ISOSpeed: Incomplete
PKEY_Photo_LensManufacturer: Incomplete
PKEY_Photo_LensModel: Incomplete
PKEY_Photo_LightSource: Incomplete
PKEY_Photo_MakerNote: Incomplete
PKEY_Photo_MakerNoteOffset: Incomplete
PKEY_Photo_MaxAperture: Incomplete
PKEY_Photo_MaxApertureDenominator: Incomplete
PKEY_Photo_MaxApertureNumerator: Incomplete
PKEY_Photo_MeteringMode: Incomplete
PKEY_Photo_MeteringModeText: Incomplete
PKEY_Photo_Orientation: Incomplete
PKEY_Photo_OrientationText: Incomplete
PKEY_Photo_PhotometricInterpretation: Incomplete
PKEY_Photo_PhotometricInterpretationText: Incomplete
PKEY_Photo_ProgramMode: Incomplete
PKEY_Photo_ProgramModeText: Incomplete
PKEY_Photo_RelatedSoundFile: Incomplete
PKEY_Photo_Saturation: Incomplete
PKEY_Photo_SaturationText: Incomplete
PKEY_Photo_Sharpness: Incomplete
PKEY_Photo_SharpnessText: Incomplete
PKEY_Photo_ShutterSpeed: Incomplete
PKEY_Photo_ShutterSpeedDenominator: Incomplete
PKEY_Photo_ShutterSpeedNumerator: Incomplete
PKEY_Photo_SubjectDistance: Incomplete
PKEY_Photo_SubjectDistanceDenominator: Incomplete
PKEY_Photo_SubjectDistanceNumerator: Incomplete
PKEY_Photo_TranscodedForSync: Incomplete
PKEY_Photo_WhiteBalance: Incomplete
PKEY_Photo_WhiteBalanceText: Incomplete
PKEY_PropGroup_Advanced: Incomplete
PKEY_PropGroup_Audio: Incomplete
PKEY_PropGroup_Calendar: Incomplete
PKEY_PropGroup_Camera: Incomplete
PKEY_PropGroup_Contact: Incomplete
PKEY_PropGroup_Content: Incomplete
PKEY_PropGroup_Description: Incomplete
PKEY_PropGroup_FileSystem: Incomplete
PKEY_PropGroup_General: Incomplete
PKEY_PropGroup_GPS: Incomplete
PKEY_PropGroup_Image: Incomplete
PKEY_PropGroup_Media: Incomplete
PKEY_PropGroup_MediaAdvanced: Incomplete
PKEY_PropGroup_Message: Incomplete
PKEY_PropGroup_Music: Incomplete
PKEY_PropGroup_Origin: Incomplete
PKEY_PropGroup_PhotoAdvanced: Incomplete
PKEY_PropGroup_RecordedTV: Incomplete
PKEY_PropGroup_Video: Incomplete
PKEY_PropList_ConflictPrompt: Incomplete
PKEY_PropList_ExtendedTileInfo: Incomplete
PKEY_PropList_FileOperationPrompt: Incomplete
PKEY_PropList_FullDetails: Incomplete
PKEY_PropList_InfoTip: Incomplete
PKEY_PropList_NonPersonal: Incomplete
PKEY_PropList_PreviewDetails: Incomplete
PKEY_PropList_PreviewTitle: Incomplete
PKEY_PropList_QuickTip: Incomplete
PKEY_PropList_TileInfo: Incomplete
PKEY_PropList_XPDetailsPanel: Incomplete
PKEY_RecordedTV_ChannelNumber: Incomplete
PKEY_RecordedTV_Credits: Incomplete
PKEY_RecordedTV_DateContentExpires: Incomplete
PKEY_RecordedTV_EpisodeName: Incomplete
PKEY_RecordedTV_IsATSCContent: Incomplete
PKEY_RecordedTV_IsClosedCaptioningAvailable: Incomplete
PKEY_RecordedTV_IsDTVContent: Incomplete
PKEY_RecordedTV_IsHDContent: Incomplete
PKEY_RecordedTV_IsRepeatBroadcast: Incomplete
PKEY_RecordedTV_IsSAP: Incomplete
PKEY_RecordedTV_NetworkAffiliation: Incomplete
PKEY_RecordedTV_OriginalBroadcastDate: Incomplete
PKEY_RecordedTV_ProgramDescription: Incomplete
PKEY_RecordedTV_RecordingTime: Incomplete
PKEY_RecordedTV_StationCallSign: Incomplete
PKEY_RecordedTV_StationName: Incomplete
PKEY_Search_AutoSummary: Incomplete
PKEY_Search_ContainerHash: Incomplete
PKEY_Search_Contents: Incomplete
PKEY_Search_EntryID: Incomplete
PKEY_Search_GatherTime: Incomplete
PKEY_Search_IsClosedDirectory: Incomplete
PKEY_Search_IsFullyContained: Incomplete
PKEY_Search_QueryFocusedSummary: Incomplete
PKEY_Search_Rank: Incomplete
PKEY_Search_Store: Incomplete
PKEY_Search_UrlToIndex: Incomplete
PKEY_Search_UrlToIndexWithModificationTime: Incomplete
PKEY_DescriptionID: Incomplete
PKEY_Link_TargetSFGAOFlagsStrings: Incomplete
PKEY_Link_TargetUrl: Incomplete
PKEY_Shell_SFGAOFlagsStrings: Incomplete
PKEY_Software_DateLastUsed: Incomplete
PKEY_Software_ProductName: Incomplete
PKEY_Sync_Comments: Incomplete
PKEY_Sync_ConflictDescription: Incomplete
PKEY_Sync_ConflictFirstLocation: Incomplete
PKEY_Sync_ConflictSecondLocation: Incomplete
PKEY_Sync_HandlerCollectionID: Incomplete
PKEY_Sync_HandlerID: Incomplete
PKEY_Sync_HandlerName: Incomplete
PKEY_Sync_HandlerType: Incomplete
PKEY_Sync_HandlerTypeLabel: Incomplete
PKEY_Sync_ItemID: Incomplete
PKEY_Sync_ItemName: Incomplete
PKEY_Task_BillingInformation: Incomplete
PKEY_Task_CompletionStatus: Incomplete
PKEY_Task_Owner: Incomplete
PKEY_Video_Compression: Incomplete
PKEY_Video_Director: Incomplete
PKEY_Video_EncodingBitrate: Incomplete
PKEY_Video_FourCC: Incomplete
PKEY_Video_FrameHeight: Incomplete
PKEY_Video_FrameRate: Incomplete
PKEY_Video_FrameWidth: Incomplete
PKEY_Video_HorizontalAspectRatio: Incomplete
PKEY_Video_SampleSize: Incomplete
PKEY_Video_StreamName: Incomplete
PKEY_Video_StreamNumber: Incomplete
PKEY_Video_TotalBitrate: Incomplete
PKEY_Video_VerticalAspectRatio: Incomplete
PKEY_Volume_FileSystem: Incomplete
PKEY_Volume_IsMappedDrive: Incomplete
PKEY_Volume_IsRoot: Incomplete
PKEY_AppUserModel_RelaunchCommand: Incomplete
PKEY_AppUserModel_RelaunchIconResource: Incomplete
PKEY_AppUserModel_RelaunchDisplayNameResource: Incomplete
PKEY_AppUserModel_ID: Incomplete
PKEY_AppUserModel_IsDestListSeparator: Incomplete
PKEY_AppUserModel_ExcludeFromShowInNewInstall: Incomplete
PKEY_AppUserModel_PreventPinning: Incomplete
PKA_SET: int
PKA_APPEND: int
PKA_DELETE: int



from typing import Final

NONE: Final = 0
ParentRelative: Final = 1
CopyFromParent: Final = 0
PointerWindow: Final = 0
InputFocus: Final = 1
PointerRoot: Final = 1
AnyPropertyType: Final = 0
AnyKey: Final = 0
AnyButton: Final = 0
AllTemporary: Final = 0
CurrentTime: Final = 0
NoSymbol: Final = 0
NoEventMask: Final = 0x0000000
KeyPressMask: Final = 0x0000001
KeyReleaseMask: Final = 0x0000002
ButtonPressMask: Final = 0x0000004
ButtonReleaseMask: Final = 0x0000008
EnterWindowMask: Final = 0x0000010
LeaveWindowMask: Final = 0x0000020
PointerMotionMask: Final = 0x0000040
PointerMotionHintMask: Final = 0x0000080
Button1MotionMask: Final = 0x0000100
Button2MotionMask: Final = 0x0000200
Button3MotionMask: Final = 0x0000400
Button4MotionMask: Final = 0x0000800
Button5MotionMask: Final = 0x0001000
ButtonMotionMask: Final = 0x0002000
KeymapStateMask: Final = 0x0004000
ExposureMask: Final = 0x0008000
VisibilityChangeMask: Final = 0x0010000
StructureNotifyMask: Final = 0x0020000
ResizeRedirectMask: Final = 0x0040000
SubstructureNotifyMask: Final = 0x0080000
SubstructureRedirectMask: Final = 0x0100000
FocusChangeMask: Final = 0x0200000
PropertyChangeMask: Final = 0x0400000
ColormapChangeMask: Final = 0x0800000
OwnerGrabButtonMask: Final = 0x1000000
KeyPress: Final = 2
KeyRelease: Final = 3
ButtonPress: Final = 4
ButtonRelease: Final = 5
MotionNotify: Final = 6
EnterNotify: Final = 7
LeaveNotify: Final = 8
FocusIn: Final = 9
FocusOut: Final = 10
KeymapNotify: Final = 11
Expose: Final = 12
GraphicsExpose: Final = 13
NoExpose: Final = 14
VisibilityNotify: Final = 15
CreateNotify: Final = 16
DestroyNotify: Final = 17
UnmapNotify: Final = 18
MapNotify: Final = 19
MapRequest: Final = 20
ReparentNotify: Final = 21
ConfigureNotify: Final = 22
ConfigureRequest: Final = 23
GravityNotify: Final = 24
ResizeRequest: Final = 25
CirculateNotify: Final = 26
CirculateRequest: Final = 27
PropertyNotify: Final = 28
SelectionClear: Final = 29
SelectionRequest: Final = 30
SelectionNotify: Final = 31
ColormapNotify: Final = 32
ClientMessage: Final = 33
MappingNotify: Final = 34
LASTEvent: Final = 35
ShiftMapIndex: Final = 0
LockMapIndex: Final = 1
ControlMapIndex: Final = 2
Mod1MapIndex: Final = 3
Mod2MapIndex: Final = 4
Mod3MapIndex: Final = 5
Mod4MapIndex: Final = 6
Mod5MapIndex: Final = 7
ShiftMask: Final = 0x0001
LockMask: Final = 0x0002
ControlMask: Final = 0x0004
Mod1Mask: Final = 0x0008
Mod2Mask: Final = 0x0010
Mod3Mask: Final = 0x0020
Mod4Mask: Final = 0x0040
Mod5Mask: Final = 0x0080
Button1Mask: Final = 0x0100
Button2Mask: Final = 0x0200
Button3Mask: Final = 0x0400
Button4Mask: Final = 0x0800
Button5Mask: Final = 0x1000
AnyModifier: Final = 0x8000
Button1: Final = 1
Button2: Final = 2
Button3: Final = 3
Button4: Final = 4
Button5: Final = 5
NotifyNormal: Final = 0
NotifyGrab: Final = 1
NotifyUngrab: Final = 2
NotifyWhileGrabbed: Final = 3
NotifyHint: Final = 1
NotifyAncestor: Final = 0
NotifyVirtual: Final = 1
NotifyInferior: Final = 2
NotifyNonlinear: Final = 3
NotifyNonlinearVirtual: Final = 4
NotifyPointer: Final = 5
NotifyPointerRoot: Final = 6
NotifyDetailNone: Final = 7
VisibilityUnobscured: Final = 0
VisibilityPartiallyObscured: Final = 1
VisibilityFullyObscured: Final = 2
PlaceOnTop: Final = 0
PlaceOnBottom: Final = 1
FamilyInternet: Final = 0
FamilyDECnet: Final = 1
FamilyChaos: Final = 2
FamilyServerInterpreted: Final = 5
FamilyInternetV6: Final = 6
PropertyNewValue: Final = 0
PropertyDelete: Final = 1
ColormapUninstalled: Final = 0
ColormapInstalled: Final = 1
GrabModeSync: Final = 0
GrabModeAsync: Final = 1
GrabSuccess: Final = 0
AlreadyGrabbed: Final = 1
GrabInvalidTime: Final = 2
GrabNotViewable: Final = 3
GrabFrozen: Final = 4
AsyncPointer: Final = 0
SyncPointer: Final = 1
ReplayPointer: Final = 2
AsyncKeyboard: Final = 3
SyncKeyboard: Final = 4
ReplayKeyboard: Final = 5
AsyncBoth: Final = 6
SyncBoth: Final = 7
RevertToNone: Final = 0
RevertToPointerRoot: Final = PointerRoot
RevertToParent: Final = 2
Success: Final = 0
BadRequest: Final = 1
BadValue: Final = 2
BadWindow: Final = 3
BadPixmap: Final = 4
BadAtom: Final = 5
BadCursor: Final = 6
BadFont: Final = 7
BadMatch: Final = 8
BadDrawable: Final = 9
BadAccess: Final = 10
BadAlloc: Final = 11
BadColor: Final = 12
BadGC: Final = 13
BadIDChoice: Final = 14
BadName: Final = 15
BadLength: Final = 16
BadImplementation: Final = 17
FirstExtensionError: Final = 128
LastExtensionError: Final = 255
InputOutput: Final = 1
InputOnly: Final = 2
CWBackPixmap: Final = 0x0001
CWBackPixel: Final = 0x0002
CWBorderPixmap: Final = 0x0004
CWBorderPixel: Final = 0x0008
CWBitGravity: Final = 0x0010
CWWinGravity: Final = 0x0020
CWBackingStore: Final = 0x0040
CWBackingPlanes: Final = 0x0080
CWBackingPixel: Final = 0x0100
CWOverrideRedirect: Final = 0x0200
CWSaveUnder: Final = 0x0400
CWEventMask: Final = 0x0800
CWDontPropagate: Final = 0x1000
CWColormap: Final = 0x2000
CWCursor: Final = 0x4000
CWX: Final = 0x01
CWY: Final = 0x02
CWWidth: Final = 0x04
CWHeight: Final = 0x08
CWBorderWidth: Final = 0x10
CWSibling: Final = 0x20
CWStackMode: Final = 0x40
ForgetGravity: Final = 0
NorthWestGravity: Final = 1
NorthGravity: Final = 2
NorthEastGravity: Final = 3
WestGravity: Final = 4
CenterGravity: Final = 5
EastGravity: Final = 6
SouthWestGravity: Final = 7
SouthGravity: Final = 8
SouthEastGravity: Final = 9
StaticGravity: Final = 10
UnmapGravity: Final = 0
NotUseful: Final = 0
WhenMapped: Final = 1
Always: Final = 2
IsUnmapped: Final = 0
IsUnviewable: Final = 1
IsViewable: Final = 2
SetModeInsert: Final = 0
SetModeDelete: Final = 1
DestroyAll: Final = 0
RetainPermanent: Final = 1
RetainTemporary: Final = 2
Above: Final = 0
Below: Final = 1
TopIf: Final = 2
BottomIf: Final = 3
Opposite: Final = 4
RaiseLowest: Final = 0
LowerHighest: Final = 1
PropModeReplace: Final = 0
PropModePrepend: Final = 1
PropModeAppend: Final = 2
GXclear: Final = 0x0
GXand: Final = 0x1
GXandReverse: Final = 0x2
GXcopy: Final = 0x3
GXandInverted: Final = 0x4
GXnoop: Final = 0x5
GXxor: Final = 0x6
GXor: Final = 0x7
GXnor: Final = 0x8
GXequiv: Final = 0x9
GXinvert: Final = 0xA
GXorReverse: Final = 0xB
GXcopyInverted: Final = 0xC
GXorInverted: Final = 0xD
GXnand: Final = 0xE
GXset: Final = 0xF
LineSolid: Final = 0
LineOnOffDash: Final = 1
LineDoubleDash: Final = 2
CapNotLast: Final = 0
CapButt: Final = 1
CapRound: Final = 2
CapProjecting: Final = 3
JoinMiter: Final = 0
JoinRound: Final = 1
JoinBevel: Final = 2
FillSolid: Final = 0
FillTiled: Final = 1
FillStippled: Final = 2
FillOpaqueStippled: Final = 3
EvenOddRule: Final = 0
WindingRule: Final = 1
ClipByChildren: Final = 0
IncludeInferiors: Final = 1
Unsorted: Final = 0
YSorted: Final = 1
YXSorted: Final = 2
YXBanded: Final = 3
CoordModeOrigin: Final = 0
CoordModePrevious: Final = 1
Complex: Final = 0
Nonconvex: Final = 1
Convex: Final = 2
ArcChord: Final = 0
ArcPieSlice: Final = 1
GCFunction: Final = 0x000001
GCPlaneMask: Final = 0x000002
GCForeground: Final = 0x000004
GCBackground: Final = 0x000008
GCLineWidth: Final = 0x000010
GCLineStyle: Final = 0x000020
GCCapStyle: Final = 0x000040
GCJoinStyle: Final = 0x000080
GCFillStyle: Final = 0x000100
GCFillRule: Final = 0x000200
GCTile: Final = 0x000400
GCStipple: Final = 0x000800
GCTileStipXOrigin: Final = 0x001000
GCTileStipYOrigin: Final = 0x002000
GCFont: Final = 0x004000
GCSubwindowMode: Final = 0x008000
GCGraphicsExposures: Final = 0x010000
GCClipXOrigin: Final = 0x020000
GCClipYOrigin: Final = 0x040000
GCClipMask: Final = 0x080000
GCDashOffset: Final = 0x100000
GCDashList: Final = 0x200000
GCArcMode: Final = 0x400000
GCLastBit: Final = 22
FontLeftToRight: Final = 0
FontRightToLeft: Final = 1
FontChange: Final = 255
XYBitmap: Final = 0
XYPixmap: Final = 1
ZPixmap: Final = 2
AllocNone: Final = 0
AllocAll: Final = 1
DoRed: Final = 0x1
DoGreen: Final = 0x2
DoBlue: Final = 0x4
CursorShape: Final = 0
TileShape: Final = 1
StippleShape: Final = 2
AutoRepeatModeOff: Final = 0
AutoRepeatModeOn: Final = 1
AutoRepeatModeDefault: Final = 2
LedModeOff: Final = 0
LedModeOn: Final = 1
KBKeyClickPercent: Final = 0x01
KBBellPercent: Final = 0x02
KBBellPitch: Final = 0x04
KBBellDuration: Final = 0x08
KBLed: Final = 0x10
KBLedMode: Final = 0x20
KBKey: Final = 0x40
KBAutoRepeatMode: Final = 0x80
MappingSuccess: Final = 0
MappingBusy: Final = 1
MappingFailed: Final = 2
MappingModifier: Final = 0
MappingKeyboard: Final = 1
MappingPointer: Final = 2
DontPreferBlanking: Final = 0
PreferBlanking: Final = 1
DefaultBlanking: Final = 2
DisableScreenSaver: Final = 0
DisableScreenInterval: Final = 0
DontAllowExposures: Final = 0
AllowExposures: Final = 1
DefaultExposures: Final = 2
ScreenSaverReset: Final = 0
ScreenSaverActive: Final = 1
HostInsert: Final = 0
HostDelete: Final = 1
EnableAccess: Final = 1
DisableAccess: Final = 0
StaticGray: Final = 0
GrayScale: Final = 1
StaticColor: Final = 2
PseudoColor: Final = 3
TrueColor: Final = 4
DirectColor: Final = 5
LSBFirst: Final = 0
MSBFirst: Final = 1



from _typeshed import Incomplete
from typing import NamedTuple

EXP_TABLE: Incomplete
LOG_TABLE: Incomplete
RS_BLOCK_OFFSET: Incomplete
RS_BLOCK_TABLE: Incomplete

def glog(n): ...
def gexp(n): ...

class Polynomial:
    num: Incomplete
    def __init__(self, num, shift) -> None: ...
    def __getitem__(self, index): ...
    def __iter__(self): ...
    def __len__(self) -> int: ...
    def __mul__(self, other): ...
    def __mod__(self, other): ...

class RSBlock(NamedTuple):
    total_count: int
    data_count: int

def rs_blocks(version, error_correction): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def eccentricity(G, v: Incomplete | None = None, sp: Incomplete | None = None, weight: Incomplete | None = None): ...
@_dispatch
def diameter(G, e: Incomplete | None = None, usebounds: bool = False, weight: Incomplete | None = None): ...
@_dispatch
def periphery(G, e: Incomplete | None = None, usebounds: bool = False, weight: Incomplete | None = None): ...
@_dispatch
def radius(G, e: Incomplete | None = None, usebounds: bool = False, weight: Incomplete | None = None): ...
@_dispatch
def center(G, e: Incomplete | None = None, usebounds: bool = False, weight: Incomplete | None = None): ...
@_dispatch
def barycenter(G, weight: Incomplete | None = None, attr: Incomplete | None = None, sp: Incomplete | None = None): ...
@_dispatch
def resistance_distance(G, nodeA, nodeB, weight: Incomplete | None = None, invert_weight: bool = True): ...



import enum
import sys
import types
from _typeshed import DataclassInstance
from builtins import type as Type  # alias to avoid name clashes with fields named "type"
from collections.abc import Callable, Iterable, Mapping
from typing import Any, Generic, Literal, Protocol, TypeVar, overload
from typing_extensions import TypeAlias, TypeGuard

if sys.version_info >= (3, 9):
    from types import GenericAlias

_T = TypeVar("_T")
_T_co = TypeVar("_T_co", covariant=True)

__all__ = [
    "dataclass",
    "field",
    "Field",
    "FrozenInstanceError",
    "InitVar",
    "MISSING",
    "fields",
    "asdict",
    "astuple",
    "make_dataclass",
    "replace",
    "is_dataclass",
]

if sys.version_info >= (3, 10):
    __all__ += ["KW_ONLY"]

_DataclassT = TypeVar("_DataclassT", bound=DataclassInstance)

# define _MISSING_TYPE as an enum within the type stubs,
# even though that is not really its type at runtime
# this allows us to use Literal[_MISSING_TYPE.MISSING]
# for background, see:
#   https://github.com/python/typeshed/pull/5900#issuecomment-895513797
class _MISSING_TYPE(enum.Enum):
    MISSING = enum.auto()

MISSING = _MISSING_TYPE.MISSING

if sys.version_info >= (3, 10):
    class KW_ONLY: ...

@overload
def asdict(obj: DataclassInstance) -> dict[str, Any]: ...
@overload
def asdict(obj: DataclassInstance, *, dict_factory: Callable[[list[tuple[str, Any]]], _T]) -> _T: ...
@overload
def astuple(obj: DataclassInstance) -> tuple[Any, ...]: ...
@overload
def astuple(obj: DataclassInstance, *, tuple_factory: Callable[[list[Any]], _T]) -> _T: ...
@overload
def dataclass(cls: None, /) -> Callable[[type[_T]], type[_T]]: ...
@overload
def dataclass(cls: type[_T], /) -> type[_T]: ...

if sys.version_info >= (3, 11):
    @overload
    def dataclass(
        *,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
        match_args: bool = True,
        kw_only: bool = False,
        slots: bool = False,
        weakref_slot: bool = False,
    ) -> Callable[[type[_T]], type[_T]]: ...

elif sys.version_info >= (3, 10):
    @overload
    def dataclass(
        *,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
        match_args: bool = True,
        kw_only: bool = False,
        slots: bool = False,
    ) -> Callable[[type[_T]], type[_T]]: ...

else:
    @overload
    def dataclass(
        *,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
    ) -> Callable[[type[_T]], type[_T]]: ...

# See https://github.com/python/mypy/issues/10750
class _DefaultFactory(Protocol[_T_co]):
    def __call__(self) -> _T_co: ...

class Field(Generic[_T]):
    name: str
    type: Type[_T]
    default: _T | Literal[_MISSING_TYPE.MISSING]
    default_factory: _DefaultFactory[_T] | Literal[_MISSING_TYPE.MISSING]
    repr: bool
    hash: bool | None
    init: bool
    compare: bool
    metadata: types.MappingProxyType[Any, Any]
    if sys.version_info >= (3, 10):
        kw_only: bool | Literal[_MISSING_TYPE.MISSING]
        def __init__(
            self,
            default: _T,
            default_factory: Callable[[], _T],
            init: bool,
            repr: bool,
            hash: bool | None,
            compare: bool,
            metadata: Mapping[Any, Any],
            kw_only: bool,
        ) -> None: ...
    else:
        def __init__(
            self,
            default: _T,
            default_factory: Callable[[], _T],
            init: bool,
            repr: bool,
            hash: bool | None,
            compare: bool,
            metadata: Mapping[Any, Any],
        ) -> None: ...

    def __set_name__(self, owner: Type[Any], name: str) -> None: ...
    if sys.version_info >= (3, 9):
        def __class_getitem__(cls, item: Any) -> GenericAlias: ...

# NOTE: Actual return type is 'Field[_T]', but we want to help type checkers
# to understand the magic that happens at runtime.
if sys.version_info >= (3, 10):
    @overload  # `default` and `default_factory` are optional and mutually exclusive.
    def field(
        *,
        default: _T,
        init: bool = True,
        repr: bool = True,
        hash: bool | None = None,
        compare: bool = True,
        metadata: Mapping[Any, Any] | None = None,
        kw_only: bool = ...,
    ) -> _T: ...
    @overload
    def field(
        *,
        default_factory: Callable[[], _T],
        init: bool = True,
        repr: bool = True,
        hash: bool | None = None,
        compare: bool = True,
        metadata: Mapping[Any, Any] | None = None,
        kw_only: bool = ...,
    ) -> _T: ...
    @overload
    def field(
        *,
        init: bool = True,
        repr: bool = True,
        hash: bool | None = None,
        compare: bool = True,
        metadata: Mapping[Any, Any] | None = None,
        kw_only: bool = ...,
    ) -> Any: ...

else:
    @overload  # `default` and `default_factory` are optional and mutually exclusive.
    def field(
        *,
        default: _T,
        init: bool = True,
        repr: bool = True,
        hash: bool | None = None,
        compare: bool = True,
        metadata: Mapping[Any, Any] | None = None,
    ) -> _T: ...
    @overload
    def field(
        *,
        default_factory: Callable[[], _T],
        init: bool = True,
        repr: bool = True,
        hash: bool | None = None,
        compare: bool = True,
        metadata: Mapping[Any, Any] | None = None,
    ) -> _T: ...
    @overload
    def field(
        *,
        init: bool = True,
        repr: bool = True,
        hash: bool | None = None,
        compare: bool = True,
        metadata: Mapping[Any, Any] | None = None,
    ) -> Any: ...

def fields(class_or_instance: DataclassInstance | type[DataclassInstance]) -> tuple[Field[Any], ...]: ...
@overload
def is_dataclass(obj: DataclassInstance) -> Literal[True]: ...
@overload
def is_dataclass(obj: type) -> TypeGuard[type[DataclassInstance]]: ...
@overload
def is_dataclass(obj: object) -> TypeGuard[DataclassInstance | type[DataclassInstance]]: ...

class FrozenInstanceError(AttributeError): ...

if sys.version_info >= (3, 9):
    _InitVarMeta: TypeAlias = type
else:
    class _InitVarMeta(type):
        # Not used, instead `InitVar.__class_getitem__` is called.
        # pyright ignore is needed because pyright (not unreasonably) thinks this
        # is an invalid use of InitVar.
        def __getitem__(self, params: Any) -> InitVar[Any]: ...  # pyright: ignore

class InitVar(Generic[_T], metaclass=_InitVarMeta):
    type: Type[_T]
    def __init__(self, type: Type[_T]) -> None: ...
    if sys.version_info >= (3, 9):
        @overload
        def __class_getitem__(cls, type: Type[_T]) -> InitVar[_T]: ...  # pyright: ignore
        @overload
        def __class_getitem__(cls, type: Any) -> InitVar[Any]: ...  # pyright: ignore

if sys.version_info >= (3, 12):
    def make_dataclass(
        cls_name: str,
        fields: Iterable[str | tuple[str, Any] | tuple[str, Any, Any]],
        *,
        bases: tuple[type, ...] = (),
        namespace: dict[str, Any] | None = None,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
        match_args: bool = True,
        kw_only: bool = False,
        slots: bool = False,
        weakref_slot: bool = False,
        module: str | None = None,
    ) -> type: ...

elif sys.version_info >= (3, 11):
    def make_dataclass(
        cls_name: str,
        fields: Iterable[str | tuple[str, Any] | tuple[str, Any, Any]],
        *,
        bases: tuple[type, ...] = (),
        namespace: dict[str, Any] | None = None,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
        match_args: bool = True,
        kw_only: bool = False,
        slots: bool = False,
        weakref_slot: bool = False,
    ) -> type: ...

elif sys.version_info >= (3, 10):
    def make_dataclass(
        cls_name: str,
        fields: Iterable[str | tuple[str, Any] | tuple[str, Any, Any]],
        *,
        bases: tuple[type, ...] = (),
        namespace: dict[str, Any] | None = None,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
        match_args: bool = True,
        kw_only: bool = False,
        slots: bool = False,
    ) -> type: ...

else:
    def make_dataclass(
        cls_name: str,
        fields: Iterable[str | tuple[str, Any] | tuple[str, Any, Any]],
        *,
        bases: tuple[type, ...] = (),
        namespace: dict[str, Any] | None = None,
        init: bool = True,
        repr: bool = True,
        eq: bool = True,
        order: bool = False,
        unsafe_hash: bool = False,
        frozen: bool = False,
    ) -> type: ...

def replace(obj: _DataclassT, /, **changes: Any) -> _DataclassT: ...



from _typeshed import Incomplete

def compact(text, *args, **kw): ...
def compact_empty_lines(text): ...
def concatenate(items, conjunction: str = "and", serial_comma: bool = False): ...
def dedent(text, *args, **kw): ...
def format(text, *args, **kw): ...
def generate_slug(text, delimiter: str = "-"): ...
def is_empty_line(text): ...
def join_lines(text): ...
def pluralize(count, singular, plural: Incomplete | None = None): ...
def pluralize_raw(count, singular, plural: Incomplete | None = None): ...
def random_string(length=(25, 100), characters=...): ...
def split(text, delimiter: str = ","): ...
def split_paragraphs(text): ...
def tokenize(text): ...
def trim_empty_lines(text): ...



from _typeshed import Unused
from collections.abc import Sequence

from matplotlib.typing import ColorType

__all__ = ["palplot", "dogplot"]

def palplot(pal: Sequence[ColorType], size: int = 1) -> None: ...
def dogplot(*_: Unused, **__: Unused) -> None: ...



from _typeshed import Incomplete
from collections.abc import Generator

from networkx.utils.backends import _dispatch

@_dispatch
def all_pairs_lowest_common_ancestor(G, pairs: Incomplete | None = None): ...
@_dispatch
def lowest_common_ancestor(G, node1, node2, default: Incomplete | None = None): ...
@_dispatch
def tree_all_pairs_lowest_common_ancestor(
    G, root: Incomplete | None = None, pairs: Incomplete | None = None
) -> Generator[Incomplete, None, None]: ...



from _typeshed import StrOrBytesPath
from typing_extensions import Self

from _cffi_backend import _CDataBase

def str_to_bytes(value: str, name: object) -> bytes: ...

class ConfigIterator:
    def __init__(self, config: _CDataBase, ptr: _CDataBase) -> None: ...
    def __del__(self) -> None: ...
    def __iter__(self) -> Self: ...
    def next(self) -> ConfigEntry: ...
    def __next__(self) -> ConfigEntry: ...

class ConfigMultivarIterator(ConfigIterator):
    def __next__(self) -> str: ...  # type: ignore[override]

class Config:
    def __init__(self, path: str | None = None) -> None: ...
    @classmethod
    def from_c(cls, repo: _CDataBase, ptr: _CDataBase) -> Config: ...
    def __del__(self) -> None: ...
    def __contains__(self, key: str) -> bool: ...
    def __getitem__(self, key: str) -> str: ...
    def __setitem__(self, key: str, value: bool | int | _CDataBase | StrOrBytesPath | None) -> None: ...
    def __delitem__(self, key: str) -> None: ...
    def __iter__(self) -> ConfigIterator: ...
    def get_multivar(self, name: str, regex: str | None = None) -> ConfigMultivarIterator: ...
    def set_multivar(self, name: str, regex: str, value: str) -> None: ...
    def delete_multivar(self, name: str, regex: str) -> None: ...
    def get_bool(self, key: str) -> bool: ...
    def get_int(self, key: str) -> int: ...
    def add_file(self, path: StrOrBytesPath, level: int = 0, force: int = 0) -> None: ...
    def snapshot(self) -> Config: ...
    @staticmethod
    def parse_bool(text: _CDataBase | bytes | str | None) -> bool: ...
    @staticmethod
    def parse_int(text: _CDataBase | bytes | str | None) -> int: ...
    @staticmethod
    def get_system_config() -> Config: ...
    @staticmethod
    def get_global_config() -> Config: ...
    @staticmethod
    def get_xdg_config() -> Config: ...

class ConfigEntry:
    def __del__(self) -> None: ...
    @property
    def c_value(self) -> _CDataBase: ...
    @property
    def raw_name(self) -> bytes: ...
    @property
    def raw_value(self) -> bytes: ...
    @property
    def level(self) -> int: ...
    @property
    def name(self) -> str: ...
    @property
    def value(self) -> str: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

from .edmondskarp import edmonds_karp

__all__ = ["gomory_hu_tree"]

default_flow_func = edmonds_karp

@_dispatch
def gomory_hu_tree(G, capacity: str = "capacity", flow_func: Incomplete | None = None): ...



from .authorization_code import AuthorizationCodeGrant as AuthorizationCodeGrant
from .client_credentials import ClientCredentialsGrant as ClientCredentialsGrant
from .implicit import ImplicitGrant as ImplicitGrant
from .refresh_token import RefreshTokenGrant as RefreshTokenGrant
from .resource_owner_password_credentials import ResourceOwnerPasswordCredentialsGrant as ResourceOwnerPasswordCredentialsGrant



from _typeshed import Incomplete

class TelegrafPluginRequest:
    openapi_types: Incomplete
    attribute_map: Incomplete
    discriminator: Incomplete
    def __init__(
        self,
        name: Incomplete | None = None,
        description: Incomplete | None = None,
        plugins: Incomplete | None = None,
        metadata: Incomplete | None = None,
        config: Incomplete | None = None,
        org_id: Incomplete | None = None,
    ) -> None: ...
    @property
    def name(self): ...
    @name.setter
    def name(self, name) -> None: ...
    @property
    def description(self): ...
    @description.setter
    def description(self, description) -> None: ...
    @property
    def plugins(self): ...
    @plugins.setter
    def plugins(self, plugins) -> None: ...
    @property
    def metadata(self): ...
    @metadata.setter
    def metadata(self, metadata) -> None: ...
    @property
    def config(self): ...
    @config.setter
    def config(self, config) -> None: ...
    @property
    def org_id(self): ...
    @org_id.setter
    def org_id(self, org_id) -> None: ...
    def to_dict(self): ...
    def to_str(self): ...
    def __eq__(self, other): ...
    def __ne__(self, other): ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def christofides(G, weight: str = "weight", tree: Incomplete | None = None): ...
@_dispatch
def traveling_salesman_problem(
    G, weight: str = "weight", nodes: Incomplete | None = None, cycle: bool = True, method: Incomplete | None = None
): ...
@_dispatch
def asadpour_atsp(G, weight: str = "weight", seed: Incomplete | None = None, source: Incomplete | None = None): ...
@_dispatch
def greedy_tsp(G, weight: str = "weight", source: Incomplete | None = None): ...
@_dispatch
def simulated_annealing_tsp(
    G,
    init_cycle,
    weight: str = "weight",
    source: Incomplete | None = None,
    # docstring says int, but it can be a float and does become a float mid-equation if alpha is also a float
    temp: float = 100,
    move: str = "1-1",
    max_iterations: int = 10,
    N_inner: int = 100,
    alpha: float = 0.01,
    seed: Incomplete | None = None,
): ...
@_dispatch
def threshold_accepting_tsp(
    G,
    init_cycle,
    weight: str = "weight",
    source: Incomplete | None = None,
    threshold: float = 1,
    move: str = "1-1",
    max_iterations: int = 10,
    N_inner: int = 100,
    alpha: float = 0.1,
    seed: Incomplete | None = None,
): ...



from collections import OrderedDict
from collections.abc import Iterator
from typing import Any

from .locale import Locale

LOCALE_SPLIT_PATTERN: Any

class LocaleDataLoader:
    def get_locale_map(
        self,
        languages: list[str] | None = None,
        locales: list[str] | None = None,
        region: str | None = None,
        use_given_order: bool = False,
        allow_conflicting_locales: bool = False,
    ) -> OrderedDict[str, list[Any] | str | int]: ...
    def get_locales(
        self,
        languages: list[str] | None = None,
        locales: list[str] | None = None,
        region: str | None = None,
        use_given_order: bool = False,
        allow_conflicting_locales: bool = False,
    ) -> Iterator[Locale]: ...
    def get_locale(self, shortname: str) -> Locale: ...

default_loader: Any



from _typeshed import Incomplete
from typing import ClassVar

from ..lexer import RegexLexer

__all__ = ["PrqlLexer"]

class PrqlLexer(RegexLexer):
    builtinTypes: ClassVar[Incomplete]
    def innerstring_rules(ttype) -> list[tuple[str, Incomplete]]: ...
    def fstring_rules(ttype) -> list[tuple[str, Incomplete]]: ...



import array
from _typeshed import Incomplete

from MySQLdb._exceptions import ProgrammingError as ProgrammingError
from MySQLdb._mysql import string_literal as string_literal
from MySQLdb.constants import FIELD_TYPE as FIELD_TYPE, FLAG as FLAG
from MySQLdb.times import (
    Date as Date,
    Date_or_None as Date_or_None,
    DateTime2literal as DateTime2literal,
    DateTime_or_None as DateTime_or_None,
    DateTimeDelta2literal as DateTimeDelta2literal,
    DateTimeDeltaType as DateTimeDeltaType,
    DateTimeType as DateTimeType,
    TimeDelta_or_None as TimeDelta_or_None,
)

NoneType: Incomplete
ArrayType = array.array

def Bool2Str(s, d): ...
def Set2Str(s, d): ...
def Thing2Str(s, d): ...
def Float2Str(o, d): ...
def None2NULL(o, d): ...
def Thing2Literal(o, d): ...
def Decimal2Literal(o, d): ...
def array2Str(o, d): ...

conversions: Incomplete



from _socket import _Address
from _typeshed import Unused
from re import Pattern
from socket import socket
from typing import Final

display_re: Final[Pattern[str]]

def get_display(display: str | None) -> tuple[str, None, str, int, int]: ...
def get_socket(dname: _Address, protocol: Unused, host: _Address, dno: int) -> socket: ...
def get_auth(sock: Unused, dname: Unused, host: Unused, dno: Unused) -> tuple[str, str]: ...



from typing import Final
from typing_extensions import TypeAlias

from Xlib.protocol import rq

class AnyEvent(rq.Event): ...
class KeyButtonPointer(rq.Event): ...
class KeyPress(KeyButtonPointer): ...
class KeyRelease(KeyButtonPointer): ...
class ButtonPress(KeyButtonPointer): ...
class ButtonRelease(KeyButtonPointer): ...
class MotionNotify(KeyButtonPointer): ...
class EnterLeave(rq.Event): ...
class EnterNotify(EnterLeave): ...
class LeaveNotify(EnterLeave): ...
class Focus(rq.Event): ...
class FocusIn(Focus): ...
class FocusOut(Focus): ...
class Expose(rq.Event): ...
class GraphicsExpose(rq.Event): ...
class NoExpose(rq.Event): ...
class VisibilityNotify(rq.Event): ...
class CreateNotify(rq.Event): ...
class DestroyNotify(rq.Event): ...
class UnmapNotify(rq.Event): ...
class MapNotify(rq.Event): ...
class MapRequest(rq.Event): ...
class ReparentNotify(rq.Event): ...
class ConfigureNotify(rq.Event): ...
class ConfigureRequest(rq.Event): ...
class GravityNotify(rq.Event): ...
class ResizeRequest(rq.Event): ...
class Circulate(rq.Event): ...
class CirculateNotify(Circulate): ...
class CirculateRequest(Circulate): ...
class PropertyNotify(rq.Event): ...
class SelectionClear(rq.Event): ...
class SelectionRequest(rq.Event): ...
class SelectionNotify(rq.Event): ...
class ColormapNotify(rq.Event): ...
class MappingNotify(rq.Event): ...
class ClientMessage(rq.Event): ...
class KeymapNotify(rq.Event): ...

_EventClass: TypeAlias = dict[
    int,
    type[
        KeyPress
        | KeyRelease
        | ButtonPress
        | ButtonRelease
        | MotionNotify
        | EnterNotify
        | LeaveNotify
        | FocusIn
        | FocusOut
        | KeymapNotify
        | Expose
        | GraphicsExpose
        | NoExpose
        | VisibilityNotify
        | CreateNotify
        | DestroyNotify
        | UnmapNotify
        | MapNotify
        | MapRequest
        | ReparentNotify
        | ConfigureNotify
        | ConfigureRequest
        | GravityNotify
        | ResizeRequest
        | CirculateNotify
        | CirculateRequest
        | PropertyNotify
        | SelectionClear
        | SelectionRequest
        | SelectionNotify
        | ColormapNotify
        | ClientMessage
        | MappingNotify
    ],
]
event_class: Final[_EventClass]



from _typeshed import Incomplete

from antlr4.Token import Token as Token

INVALID_INTERVAL: Incomplete

class Tree: ...
class SyntaxTree(Tree): ...
class ParseTree(SyntaxTree): ...
class RuleNode(ParseTree): ...
class TerminalNode(ParseTree): ...
class ErrorNode(TerminalNode): ...

class ParseTreeVisitor:
    def visit(self, tree): ...
    def visitChildren(self, node): ...
    def visitTerminal(self, node): ...
    def visitErrorNode(self, node): ...
    def defaultResult(self) -> None: ...
    def aggregateResult(self, aggregate, nextResult): ...
    def shouldVisitNextChild(self, node, currentResult): ...

class ParseTreeListener:
    def visitTerminal(self, node: TerminalNode): ...
    def visitErrorNode(self, node: ErrorNode): ...
    def enterEveryRule(self, ctx): ...
    def exitEveryRule(self, ctx): ...

class TerminalNodeImpl(TerminalNode):
    parentCtx: Incomplete
    symbol: Incomplete
    def __init__(self, symbol: Token) -> None: ...
    def __setattr__(self, key, value) -> None: ...
    def getChild(self, i: int): ...
    def getSymbol(self): ...
    def getParent(self): ...
    def getPayload(self): ...
    def getSourceInterval(self): ...
    def getChildCount(self): ...
    def accept(self, visitor: ParseTreeVisitor): ...
    def getText(self): ...

class ErrorNodeImpl(TerminalNodeImpl, ErrorNode):
    def __init__(self, token: Token) -> None: ...
    def accept(self, visitor: ParseTreeVisitor): ...

class ParseTreeWalker:
    DEFAULT: Incomplete
    def walk(self, listener: ParseTreeListener, t: ParseTree): ...
    def enterRule(self, listener: ParseTreeListener, r: RuleNode): ...
    def exitRule(self, listener: ParseTreeListener, r: RuleNode): ...



from _typeshed import Incomplete

from antlr4.Token import CommonToken as CommonToken

class TokenFactory: ...

class CommonTokenFactory(TokenFactory):
    DEFAULT: Incomplete
    copyText: Incomplete
    def __init__(self, copyText: bool = False) -> None: ...
    def create(
        self, source: tuple[Incomplete, ...], type: int, text: str, channel: int, start: int, stop: int, line: int, column: int
    ): ...
    def createThin(self, type: int, text: str): ...



from _typeshed import Incomplete
from typing import Generic, NamedTuple, TypeVar, overload
from typing_extensions import TypeAlias

from qrcode.image.base import BaseImage

ModulesType: TypeAlias = list[list[bool | None]]
precomputed_qr_blanks: dict[int, ModulesType]

def make(data: Incomplete | None = None, **kwargs): ...
def copy_2d_array(x): ...

class ActiveWithNeighbors(NamedTuple):
    NW: bool
    N: bool
    NE: bool
    W: bool
    me: bool
    E: bool
    SW: bool
    S: bool
    SE: bool
    def __bool__(self) -> bool: ...

GenericImage = TypeVar("GenericImage", bound=BaseImage)  # noqa: Y001
GenericImageLocal = TypeVar("GenericImageLocal", bound=BaseImage)  # noqa: Y001

class QRCode(Generic[GenericImage]):
    modules: ModulesType
    error_correction: Incomplete
    box_size: Incomplete
    border: Incomplete
    image_factory: Incomplete
    def __init__(
        self,
        version: Incomplete | None = None,
        error_correction=0,
        box_size: int = 10,
        border: int = 4,
        image_factory: type[GenericImage] | None = None,
        mask_pattern: Incomplete | None = None,
    ) -> None: ...
    @property
    def version(self) -> int: ...
    @property
    def mask_pattern(self): ...
    modules_count: int
    data_cache: Incomplete
    data_list: Incomplete
    def clear(self) -> None: ...
    def add_data(self, data, optimize: int = 20) -> None: ...
    def make(self, fit: bool = True) -> None: ...
    def makeImpl(self, test, mask_pattern) -> None: ...
    def setup_position_probe_pattern(self, row, col) -> None: ...
    def best_fit(self, start: Incomplete | None = None): ...
    def best_mask_pattern(self): ...
    def print_tty(self, out: Incomplete | None = None) -> None: ...
    def print_ascii(self, out: Incomplete | None = None, tty: bool = False, invert: bool = False): ...
    @overload
    def make_image(self, image_factory: None = None, **kwargs) -> GenericImage: ...
    @overload
    def make_image(self, image_factory: type[GenericImageLocal], **kwargs) -> GenericImageLocal: ...
    def is_constrained(self, row: int, col: int) -> bool: ...
    def setup_timing_pattern(self) -> None: ...
    def setup_position_adjust_pattern(self) -> None: ...
    def setup_type_number(self, test) -> None: ...
    def setup_type_info(self, test, mask_pattern) -> None: ...
    def map_data(self, data, mask_pattern) -> None: ...
    def get_matrix(self): ...
    def active_with_neighbors(self, row: int, col: int) -> ActiveWithNeighbors: ...



from _typeshed import Incomplete

from networkx.utils.backends import _dispatch

@_dispatch
def greedy_modularity_communities(
    G, weight: Incomplete | None = None, resolution: float = 1, cutoff: int = 1, best_n: Incomplete | None = None
): ...
@_dispatch
def naive_greedy_modularity_communities(G, resolution: float = 1, weight: Incomplete | None = None): ...



from _typeshed import Incomplete

from influxdb_client.service._base_service import _BaseService

class ReplicationsService(_BaseService):
    def __init__(self, api_client: Incomplete | None = None) -> None: ...
    def delete_replication_by_id(self, replication_id, **kwargs): ...
    def delete_replication_by_id_with_http_info(self, replication_id, **kwargs): ...
    async def delete_replication_by_id_async(self, replication_id, **kwargs): ...
    def get_replication_by_id(self, replication_id, **kwargs): ...
    def get_replication_by_id_with_http_info(self, replication_id, **kwargs): ...
    async def get_replication_by_id_async(self, replication_id, **kwargs): ...
    def get_replications(self, org_id, **kwargs): ...
    def get_replications_with_http_info(self, org_id, **kwargs): ...
    async def get_replications_async(self, org_id, **kwargs): ...
    def patch_replication_by_id(self, replication_id, replication_update_request, **kwargs): ...
    def patch_replication_by_id_with_http_info(self, replication_id, replication_update_request, **kwargs): ...
    async def patch_replication_by_id_async(self, replication_id, replication_update_request, **kwargs): ...
    def post_replication(self, replication_creation_request, **kwargs): ...
    def post_replication_with_http_info(self, replication_creation_request, **kwargs): ...
    async def post_replication_async(self, replication_creation_request, **kwargs): ...
    def post_validate_replication_by_id(self, replication_id, **kwargs): ...
    def post_validate_replication_by_id_with_http_info(self, replication_id, **kwargs): ...
    async def post_validate_replication_by_id_async(self, replication_id, **kwargs): ...
